@@ -15,26 +15,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """
-**Source Code**: https://github.com/sertit/eoreader
-
-.. include:: ../documentation/index.md
-
-_____
-
-.. include:: ../documentation/main_features.md
-
-_____
-
-.. include:: ../documentation/optical.md
-
-_____
-
-.. include:: ../documentation/sar.md
-
+**EOReader** library
 """
-
-__pdoc__ = {
-    "eoreader.data": False,
-}
-
-__version__ = "0.3.1-2"
+__version__ = "0.4.0"
+__title__ = "eoreader"
+__description__ = (
+    "Remote-sensing opensource python library reading optical and SAR sensors, "
+    "loading and stacking bands, clouds, DEM and index."
+)
+__author__ = "ICube-SERTIT"
+__author_email__ = "dev-sertit@unistra.fr"
+__url__ = "https://github.com/sertit/eoreader"
+__license__ = "Apache 2.0"
+__copyright__ = "Copyright 2021, SERTIT-ICube - France, https://sertit.unistra.fr/"
+__documentation__ = "https://eoreader.readthedocs.io"
