@@ -37,25 +37,25 @@ class L7Product(LandsatProduct):
         return 30.0
 
     def _set_product_type(self) -> None:
-        """Get products type"""
+        """Set products type"""
         self._set_etm_product_type()
 
     def footprint(self) -> gpd.GeoDataFrame:
         """
-        Get real footprint of the products (without nodata, in french == emprise utile)
+        Get real footprint in UTM of the products (without nodata, in french == emprise utile)
 
         .. WARNING::
             As Landsat 7 is broken (with nodata stripes all over the bands),
             the footprint is not easily computed and may take some time to be delivered.
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"LC08_L1GT_023030_20200518_20200527_01_T2"
-        >>> prod = Reader().open(path)
-        >>> prod.footprint()
-           index                                           geometry
-        0      0  POLYGON ((366165.000 4899735.000, 366165.000 4...
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"LC08_L1GT_023030_20200518_20200527_01_T2"
+            >>> prod = Reader().open(path)
+            >>> prod.footprint()
+               index                                           geometry
+            0      0  POLYGON ((366165.000 4899735.000, 366165.000 4...
 
         Overload of the generic function because landsat nodata seems to be different in QA than in regular bands.
         Indeed, nodata pixels vary according to the band sensor footprint,
@@ -86,7 +86,7 @@ class L7Product(LandsatProduct):
             gap_msk, values=1, keep_values=False, dissolve=True
         )
 
-        # Needs a dataframe to be dissolved
-        footprint = footprint.convex_hull
+        # Keep only the convex hull
+        footprint.geometry = footprint.geometry.convex_hull
 
-        return gpd.GeoDataFrame(geometry=footprint.geometry, crs=footprint.crs)
+        return footprint
