@@ -15,7 +15,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """ Landsat products """
-import glob
 import logging
 import os
 import tarfile
@@ -64,7 +63,7 @@ class LandsatProductType(ListEnum):
 class LandsatCollection(ListEnum):
     """
     Landsat collection number.
-    See [here](https://www.usgs.gov/media/files/landsat-collection-1-vs-collection-2-summary) for more information
+    See `here <https://www.usgs.gov/media/files/landsat-collection-1-vs-collection-2-summary>`_ for more information
     """
 
     COL_1 = "01"
@@ -82,14 +81,18 @@ class LandsatProduct(OpticalProduct):
     """
 
     def __init__(
-        self, product_path: str, archive_path: str = None, output_path=None
+        self,
+        product_path: str,
+        archive_path: str = None,
+        output_path: str = None,
+        remove_tmp: bool = False,
     ) -> None:
         # Private
         self._collection = None
         self._quality_id = None
 
         # Initialization from the super class
-        super().__init__(product_path, archive_path, output_path)
+        super().__init__(product_path, archive_path, output_path, remove_tmp)
 
     def _set_collection(self):
         """Set Landsat collection"""
@@ -123,6 +126,7 @@ class LandsatProduct(OpticalProduct):
 
         Returns:
             str: band path
+            str: band path
 
         """
         if self.is_archived:
@@ -139,16 +143,16 @@ class LandsatProduct(OpticalProduct):
 
     def footprint(self) -> gpd.GeoDataFrame:
         """
-        Get real footprint of the products (without nodata, in french == emprise utile)
+        Get real footprint in UTM of the products (without nodata, in french == emprise utile)
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"LC08_L1GT_023030_20200518_20200527_01_T2"
-        >>> prod = Reader().open(path)
-        >>> prod.footprint()
-           index                                           geometry
-        0      0  POLYGON ((366165.000 4899735.000, 366165.000 4...
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"LC08_L1GT_023030_20200518_20200527_01_T2"
+            >>> prod = Reader().open(path)
+            >>> prod.footprint()
+               index                                           geometry
+            0      0  POLYGON ((366165.000 4899735.000, 366165.000 4...
 
         Overload of the generic function because landsat nodata seems to be different in QA than in regular bands.
         Indeed, nodata pixels vary according to the band sensor footprint,
@@ -166,21 +170,24 @@ class LandsatProduct(OpticalProduct):
         # Vectorize the nodata band (rasters_rio is faster)
         footprint = rasters_rio.vectorize(
             nodata_band, values=1, keep_values=False, dissolve=True
-        ).convex_hull
+        )
 
-        return gpd.GeoDataFrame(geometry=footprint.geometry, crs=footprint.crs)
+        # Keep only the convex hull
+        footprint.geometry = footprint.geometry.convex_hull
+
+        return footprint
 
     def _get_tile_name(self) -> str:
         """
         Retrieve tile name
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"LC08_L1GT_023030_20200518_20200527_01_T2"
-        >>> prod = Reader().open(path)
-        >>> prod.get_tile_name()
-        '023030'
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"LC08_L1GT_023030_20200518_20200527_01_T2"
+            >>> prod = Reader().open(path)
+            >>> prod.get_tile_name()
+            '023030'
 
         Returns:
             str: Tile name
@@ -189,7 +196,7 @@ class LandsatProduct(OpticalProduct):
 
     @abstractmethod
     def _set_product_type(self) -> None:
-        """Get products type"""
+        """Set products type"""
         raise NotImplementedError("This method should be implemented by a child class")
 
     def _set_mss_product_type(self, version: int) -> None:
@@ -278,15 +285,15 @@ class LandsatProduct(OpticalProduct):
         """
         Get the product's acquisition datetime, with format `YYYYMMDDTHHMMSS` <-> `%Y%m%dT%H%M%S`
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"LC08_L1GT_023030_20200518_20200527_01_T2"
-        >>> prod = Reader().open(path)
-        >>> prod.get_datetime(as_datetime=True)
-        datetime.datetime(2020, 5, 18, 16, 34, 7)
-        >>> prod.get_datetime(as_datetime=False)
-        '20200518T163407'
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"LC08_L1GT_023030_20200518_20200527_01_T2"
+            >>> prod = Reader().open(path)
+            >>> prod.get_datetime(as_datetime=True)
+            datetime.datetime(2020, 5, 18, 16, 34, 7)
+            >>> prod.get_datetime(as_datetime=False)
+            '20200518T163407'
 
         Args:
             as_datetime (bool): Return the date as a datetime.datetime. If false, returns a string.
@@ -318,24 +325,24 @@ class LandsatProduct(OpticalProduct):
         """
         Return the paths of required bands.
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> from eoreader.bands.alias import *
-        >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.get_band_paths([GREEN, RED])
-        {
-            <OpticalBandNames.GREEN: 'GREEN'>:
-                'LC08_L1GT_023030_20200518_20200527_01_T2\\LC08_L1GT_023030_20200518_20200527_01_T2_B3.TIF',
-            <OpticalBandNames.RED: 'RED'>:
-                'LC08_L1GT_023030_20200518_20200527_01_T2\\LC08_L1GT_023030_20200518_20200527_01_T2_B4.TIF'
-        }
+        .. code-block:: python
 
-        ```
+            >>> from eoreader.reader import Reader
+            >>> from eoreader.bands.alias import *
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_band_paths([GREEN, RED])
+            {
+                <OpticalBandNames.GREEN: 'GREEN'>:
+                    'LC08_L1GT_023030_20200518_20200527_01_T2\\LC08_L1GT_023030_20200518_20200527_01_T2_B3.TIF',
+                <OpticalBandNames.RED: 'RED'>:
+                    'LC08_L1GT_023030_20200518_20200527_01_T2\\LC08_L1GT_023030_20200518_20200527_01_T2_B4.TIF'
+            }
 
         Args:
             band_list (list): List of the wanted bands
             resolution (float): Useless here
+            size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
 
         Returns:
             dict: Dictionary containing the path of each queried band
@@ -349,12 +356,17 @@ class LandsatProduct(OpticalProduct):
                 )
             band_nb = self.band_names[band]
 
-            try:
-                band_paths[band] = self._get_path(f"_B{band_nb}")
-            except FileNotFoundError as ex:
-                raise InvalidProductError(
-                    f"Non existing {band} ({band_nb}) band for {self.path}"
-                ) from ex
+            # Get clean band path
+            clean_band = self._get_clean_band_path(band, resolution=resolution)
+            if os.path.isfile(clean_band):
+                band_paths[band] = clean_band
+            else:
+                try:
+                    band_paths[band] = self._get_path(f"_B{band_nb}")
+                except FileNotFoundError as ex:
+                    raise InvalidProductError(
+                        f"Non existing {band} ({band_nb}) band for {self.path}"
+                    ) from ex
 
         return band_paths
 
@@ -367,33 +379,34 @@ class LandsatProduct(OpticalProduct):
          - a `pandas.DataFrame` whatever its collection is (by default for collection 1)
          - a XML root + its namespace if the product is retrieved from the 2nd collection (by default for collection 2)
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"LC08_L1GT_023030_20200518_20200527_01_T2"
-        >>> prod = Reader().open(path)
+        .. code-block:: python
 
-        >>> # COLLECTION 1 : Open metadata as panda DataFrame
-        >>> prod.read_mtd()
-        NAME                                           ORIGIN  ...    RESAMPLING_OPTION
-        value  "Image courtesy of the U.S. Geological Survey"  ...  "CUBIC_CONVOLUTION"
-        [1 rows x 197 columns]
+            >>> from eoreader.reader import Reader
+            >>> path = r"LC08_L1GT_023030_20200518_20200527_01_T2"
+            >>> prod = Reader().open(path)
 
-        >>> # COLLECTION 2 : Open metadata as XML
-        >>> path = r"LC08_L1TP_200030_20201220_20210310_02_T1"  # Collection 2
-        >>> prod = Reader().open(path)
-        >>> prod.read_mtd()
-        (<Element LANDSAT_METADATA_FILE at 0x19229016048>, '')
+            >>> # COLLECTION 1 : Open metadata as panda DataFrame
+            >>> prod.read_mtd()
+            NAME                                           ORIGIN  ...    RESAMPLING_OPTION
+            value  "Image courtesy of the U.S. Geological Survey"  ...  "CUBIC_CONVOLUTION"
+            [1 rows x 197 columns]
+
+            >>> # COLLECTION 2 : Open metadata as XML
+            >>> path = r"LC08_L1TP_200030_20201220_20210310_02_T1"  # Collection 2
+            >>> prod = Reader().open(path)
+            >>> prod.read_mtd()
+            (<Element LANDSAT_METADATA_FILE at 0x19229016048>, {})
+
+            >>> # COLLECTION 2 : Force to pandas.DataFrame
+            >>> prod.read_mtd(force_pd=True)
+            NAME                                           ORIGIN  ...    RESAMPLING_OPTION
+            value  "Image courtesy of the U.S. Geological Survey"  ...  "CUBIC_CONVOLUTION"
+            [1 rows x 263 columns]
 
-        >>> # COLLECTION 2 : Force to pandas.DataFrame
-        >>> prod.read_mtd(force_pd=True)
-        NAME                                           ORIGIN  ...    RESAMPLING_OPTION
-        value  "Image courtesy of the U.S. Geological Survey"  ...  "CUBIC_CONVOLUTION"
-        [1 rows x 263 columns]
-        ```
         Args:
             force_pd (bool): If collection 2, return a pandas.DataFrame instead of a XML root + namespace
         Returns:
-            pd.DataFrame: Metadata as a Pandas DataFrame
+            Any: Metadata as a Pandas.DataFrame or as (etree._Element, dict): Metadata XML root and its namespaces
         """
         # WARNING: always use force_pd in this class !
         as_pd = (self._collection == LandsatCollection.COL_1) or force_pd
@@ -444,49 +457,33 @@ class LandsatProduct(OpticalProduct):
             if tar_ds:
                 tar_ds.close()
         else:
-            if self.is_archived:
-                root = files.read_archived_xml(self.path, f".*{self.name}_MTL.xml")
-            else:
-                # ONLY FOR COLLECTION 2
-                try:
-                    mtd_file = glob.glob(
-                        os.path.join(self.path, f"{self.name}_MTL.xml")
-                    )[0]
-
-                    # pylint: disable=I1101:
-                    # Module 'lxml.etree' has no 'parse' member, but source is unavailable.
-                    xml_tree = etree.parse(mtd_file)
-                    root = xml_tree.getroot()
-                except IndexError as ex:
-                    raise InvalidProductError(
-                        f"Metadata file ({self.name}.xml) not found in {self.path}"
-                    ) from ex
-
-            # Get namespace
-            namespace = ""  # No namespace here
-
-            mtd_data = (root, namespace)
+            # Open XML metadata
+            mtd_from_path = f"{self.name}_MTL.xml"
+            mtd_archived = f".*{self.name}_MTL.xml"
+            mtd_data = self._read_mtd(mtd_from_path, mtd_archived)
 
         return mtd_data
 
     def _read_band(
         self,
         path: str,
+        band: BandNames = None,
         resolution: Union[tuple, list, float] = None,
         size: Union[list, tuple] = None,
     ) -> XDS_TYPE:
         """
-        Read band from a dataset.
+        Read band from disk.
 
         .. WARNING::
-            Invalid pixels are not managed here !
+            Invalid pixels are not managed here
 
         Args:
             path (str): Band path
+            band (BandNames): Band to read
             resolution (Union[tuple, list, float]): Resolution of the wanted band, in dataset resolution unit (X, Y)
             size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
         Returns:
-            XDS_TYPE: Radiometrically coherent band, saved as float 32 and its metadata
+            XDS_TYPE: Band xarray
 
         """
         # Get band name: the last number of the filename:
@@ -496,9 +493,8 @@ class LandsatProduct(OpticalProduct):
         else:
             filename = files.get_filename(path)
 
-        band_name = filename[-1]
         if self._quality_id in filename or self._nodata_band_id in filename:
-            band = rasters.read(
+            band_xda = rasters.read(
                 path,
                 resolution=resolution,
                 size=size,
@@ -506,8 +502,16 @@ class LandsatProduct(OpticalProduct):
                 masked=False,
             ).astype(np.uint16)
         else:
+            # Manage to get the band_name as a number
+            # Original band name
+            band_name = filename[-1]
+            if not band_name.isdigit():
+                # Clean band name: {self.condensed_name}_{band.name}_{res_str}_clean.tif",
+                band_name = filename.split("_")[-3]
+                band_name = str(self.band_names[getattr(obn, band_name)])
+
             # Read band (call superclass generic method)
-            band = rasters.read(
+            band_xda = rasters.read(
                 path, resolution=resolution, size=size, resampling=Resampling.bilinear
             ).astype(np.float32)
 
@@ -533,9 +537,9 @@ class LandsatProduct(OpticalProduct):
                 c_add = 0
 
             # Compute the correct radiometry of the band and set no data to 0
-            band = c_mul * band + c_add  # Already in float
+            band_xda = c_mul * band_xda + c_add  # Already in float
 
-        return band
+        return band_xda
 
     # pylint: disable=R0913
     # R0913: Too many arguments (6/5) (too-many-arguments)
@@ -637,13 +641,13 @@ class LandsatProduct(OpticalProduct):
         """
         Get Mean Sun angles (Azimuth and Zenith angles)
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"LC08_L1GT_023030_20200518_20200527_01_T2.SAFE.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.get_mean_sun_angles()
-        (140.80752656, 61.93065805)
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"LC08_L1GT_023030_20200518_20200527_01_T2.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_mean_sun_angles()
+            (140.80752656, 61.93065805)
 
         Returns:
             (float, float): Mean Azimuth and Zenith angle
@@ -651,7 +655,7 @@ class LandsatProduct(OpticalProduct):
         # Retrieve angles
         mtd_data = self.read_mtd(force_pd=True)
         azimuth_angle = float(mtd_data.SUN_AZIMUTH.value)
-        zenith_angle = float(mtd_data.SUN_ELEVATION.value)
+        zenith_angle = 90.0 - float(mtd_data.SUN_ELEVATION.value)
 
         return azimuth_angle, zenith_angle
 
@@ -671,8 +675,6 @@ class LandsatProduct(OpticalProduct):
 
         - (COL 1)[https://www.usgs.gov/land-resources/nli/landsat/landsat-collection-1-level-1-quality-assessment-band]
         - (COL 2)[https://www.usgs.gov/core-science-systems/nli/landsat/landsat-collection-2-quality-assessment-bands]
-        True
-        ```
         """
         if self.product_type == LandsatProductType.L1_OLCI:
             has_band = True
@@ -689,7 +691,6 @@ class LandsatProduct(OpticalProduct):
     def _mss_has_cloud_band(band: BandNames) -> bool:
         """
         Does this products has the specified cloud band ?
-        ```
         """
         if band in [RAW_CLOUDS, CLOUDS, ALL_CLOUDS]:
             has_band = True
@@ -701,7 +702,6 @@ class LandsatProduct(OpticalProduct):
     def _e_tm_has_cloud_band(band: BandNames) -> bool:
         """
         Does this products has the specified cloud band ?
-        ```
         """
         if band in [RAW_CLOUDS, CLOUDS, ALL_CLOUDS, SHADOWS]:
             has_band = True
@@ -713,7 +713,7 @@ class LandsatProduct(OpticalProduct):
         self, bands: list, resolution: float = None, size: Union[list, tuple] = None
     ) -> dict:
         """
-        Load cloud files as numpy arrays with the same resolution (and same metadata).
+        Load cloud files as xarrays.
 
         Read Landsat clouds from QA mask.
         See here for clouds_values:
@@ -752,7 +752,7 @@ class LandsatProduct(OpticalProduct):
 
     def _load_mss_clouds(self, qa_arr: XDS_TYPE, band_list: list) -> dict:
         """
-        Load cloud files as numpy arrays with the same resolution (and same metadata).
+        Load cloud files as xarrays.
 
         Read Landsat-MSS clouds from QA mask.
         See here for clouds_values:
@@ -798,7 +798,7 @@ class LandsatProduct(OpticalProduct):
         self, qa_arr: XDS_TYPE, band_list: Union[list, BandNames]
     ) -> dict:
         """
-        Load cloud files as numpy arrays with the same resolution (and same metadata).
+        Load cloud files as xarrays.
 
         Read Landsat-(E)TM clouds from QA mask.
         See here for clouds_values:
@@ -860,7 +860,7 @@ class LandsatProduct(OpticalProduct):
         self, qa_arr: XDS_TYPE, band_list: Union[list, BandNames]
     ) -> dict:
         """
-        Load cloud files as numpy arrays with the same resolution (and same metadata).
+        Load cloud files as xarrays.
 
         Read Landsat-OLCI clouds from QA mask.
         See here for clouds_values:
