@@ -34,6 +34,7 @@ from eoreader.bands.alias import (
     is_index,
     is_optical_band,
     is_sar_band,
+    to_str,
 )
 from eoreader.bands.bands import BandNames
 from eoreader.bands.bands import OpticalBandNames as obn
@@ -64,13 +65,13 @@ class OpticalProduct(Product):
         """
         Get default band: `GREEN` for optical data as every optical satellite has a GREEN band.
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.get_default_band()
-        <OpticalBandNames.GREEN: 'GREEN'>
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_default_band()
+            <OpticalBandNames.GREEN: 'GREEN'>
 
         Returns:
             str: Default band
@@ -81,13 +82,13 @@ class OpticalProduct(Product):
         """
         Get default band (`GREEN` for optical data) path.
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.get_default_band_path()
-        'zip+file://S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip!/S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE/GRANULE/L1C_T30TTK_A027018_20200824T111345/IMG_DATA/T30TTK_20200824T110631_B03.jp2'
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_default_band_path()
+            'zip+file://S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip!/S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE/GRANULE/L1C_T30TTK_A027018_20200824T111345/IMG_DATA/T30TTK_20200824T110631_B03.jp2'
 
         Returns:
             str: Default band path
@@ -99,13 +100,13 @@ class OpticalProduct(Product):
         """
         Get UTM projection of the tile
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.utm_crs()
-        CRS.from_epsg(32630)
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.crs()
+            CRS.from_epsg(32630)
 
         Returns:
             rasterio.crs.CRS: CRS object
@@ -120,44 +121,44 @@ class OpticalProduct(Product):
         """
         Get UTM extent of the tile
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.utm_extent()
-                                                    geometry
-        0  POLYGON ((309780.000 4390200.000, 309780.000 4...
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.extent()
+                                                        geometry
+            0  POLYGON ((309780.000 4390200.000, 309780.000 4...
 
         Returns:
             gpd.GeoDataFrame: Footprint in UTM
         """
         # Get extent
-        return rasters.get_extent(self.get_default_band_path())
+        return rasters.get_extent(self.get_default_band_path()).to_crs(self.crs())
 
     def get_existing_bands(self) -> list:
         """
         Return the existing band paths.
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.get_existing_bands()
-        [<OpticalBandNames.CA: 'COASTAL_AEROSOL'>,
-        <OpticalBandNames.BLUE: 'BLUE'>,
-        <OpticalBandNames.GREEN: 'GREEN'>,
-        <OpticalBandNames.RED: 'RED'>,
-        <OpticalBandNames.VRE_1: 'VEGETATION_RED_EDGE_1'>,
-        <OpticalBandNames.VRE_2: 'VEGETATION_RED_EDGE_2'>,
-        <OpticalBandNames.VRE_3: 'VEGETATION_RED_EDGE_3'>,
-        <OpticalBandNames.NIR: 'NIR'>,
-        <OpticalBandNames.NNIR: 'NARROW_NIR'>,
-        <OpticalBandNames.WV: 'WATER_VAPOUR'>,
-        <OpticalBandNames.CIRRUS: 'CIRRUS'>,
-        <OpticalBandNames.SWIR_1: 'SWIR_1'>,
-        <OpticalBandNames.SWIR_2: 'SWIR_2'>]
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_existing_bands()
+            [<OpticalBandNames.CA: 'COASTAL_AEROSOL'>,
+            <OpticalBandNames.BLUE: 'BLUE'>,
+            <OpticalBandNames.GREEN: 'GREEN'>,
+            <OpticalBandNames.RED: 'RED'>,
+            <OpticalBandNames.VRE_1: 'VEGETATION_RED_EDGE_1'>,
+            <OpticalBandNames.VRE_2: 'VEGETATION_RED_EDGE_2'>,
+            <OpticalBandNames.VRE_3: 'VEGETATION_RED_EDGE_3'>,
+            <OpticalBandNames.NIR: 'NIR'>,
+            <OpticalBandNames.NNIR: 'NARROW_NIR'>,
+            <OpticalBandNames.WV: 'WATER_VAPOUR'>,
+            <OpticalBandNames.CIRRUS: 'CIRRUS'>,
+            <OpticalBandNames.SWIR_1: 'SWIR_1'>,
+            <OpticalBandNames.SWIR_2: 'SWIR_2'>]
 
         Returns:
             list: List of existing bands in the products
@@ -168,17 +169,17 @@ class OpticalProduct(Product):
         """
         Return the existing band paths.
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.get_existing_band_paths()
-        {
-            <OpticalBandNames.CA: 'COASTAL_AEROSOL'>: 'zip+file://S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip!/S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE/GRANULE/L1C_T30TTK_A027018_20200824T111345/IMG_DATA/T30TTK_20200824T110631_B01.jp2',
-            ...,
-            <OpticalBandNames.SWIR_2: 'SWIR_2'>: 'zip+file://S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip!/S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE/GRANULE/L1C_T30TTK_A027018_20200824T111345/IMG_DATA/T30TTK_20200824T110631_B12.jp2'
-        }
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_existing_band_paths()
+            {
+                <OpticalBandNames.CA: 'COASTAL_AEROSOL'>: 'zip+file://S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip!/S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE/GRANULE/L1C_T30TTK_A027018_20200824T111345/IMG_DATA/T30TTK_20200824T110631_B01.jp2',
+                ...,
+                <OpticalBandNames.SWIR_2: 'SWIR_2'>: 'zip+file://S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip!/S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE/GRANULE/L1C_T30TTK_A027018_20200824T111345/IMG_DATA/T30TTK_20200824T110631_B12.jp2'
+            }
 
         Returns:
             dict: Dictionary containing the path of each queried band
@@ -206,15 +207,31 @@ class OpticalProduct(Product):
         """
         # Open bands and get array (resampled if needed)
         band_arrays = {}
-        for band_name, band_path in band_paths.items():
+        for band, band_path in band_paths.items():
             # Read band
-            band_arrays[band_name] = self._read_band(
-                band_path, resolution=resolution, size=size
-            )
-            band_arrays[band_name] = self._manage_invalid_pixels(
-                band_arrays[band_name], band_name, resolution=resolution, size=size
+            LOGGER.debug(f"Read {band.name}")
+            band_arrays[band] = self._read_band(
+                band_path, band=band, resolution=resolution, size=size
             )
 
+            # Write on disk in order not to reprocess band everytime
+            # (invalid pix management can be time consuming)
+            if not resolution:
+                resolution = band_arrays[band].rio.resolution()[0]
+            clean_band = self._get_clean_band_path(band, resolution=resolution)
+            if not os.path.isfile(clean_band):
+                # Manage invalid pixels
+                LOGGER.debug(f"Manage invalid pixels for band {band.name}")
+                band_arrays[band] = self._manage_invalid_pixels(
+                    band_arrays[band], band=band, resolution=resolution, size=size
+                )
+
+                # Write on disk
+
+                rasters.write(
+                    band_arrays[band].rename(f"{to_str(band)[0]} CLEAN"), clean_band
+                )
+
         return band_arrays
 
     # pylint: disable=R0913
@@ -260,7 +277,7 @@ class OpticalProduct(Product):
             mask = np.expand_dims(mask, axis=0)
 
         # Set masked values to nodata
-        return band_arr.where(mask == 0, np.nan)
+        return band_arr.where(mask == 0)
 
     def _load(
         self, bands: list, resolution: float = None, size: Union[list, tuple] = None
@@ -306,26 +323,33 @@ class OpticalProduct(Product):
             elif is_clouds(idx_or_band):
                 clouds_list.append(idx_or_band)
 
+        # Check if DEM is set and exists
+        if dem_list:
+            self._check_dem_path()
+
         # Get all bands to be open
         bands_to_load = band_list.copy()
         for idx in index_list:
             bands_to_load += index.NEEDED_BANDS[idx]
 
         # Load band arrays (only keep unique bands: open them only one time !)
-        bands = self._load_bands(
-            list(set(bands_to_load)), resolution=resolution, size=size
-        )
+        unique_bands = list(set(bands_to_load))
+        LOGGER.debug(f"Loading bands {to_str(unique_bands)}")
+        bands = self._load_bands(unique_bands, resolution=resolution, size=size)
 
         # Compute index (they conserve the nodata)
+        LOGGER.debug(f"Loading index {to_str(index_list)}")
         bands_dict = {idx: idx(bands) for idx in index_list}
 
         # Add bands
         bands_dict.update({band: bands[band] for band in band_list})
 
         # Add DEM
+        LOGGER.debug(f"Loading DEM bands {to_str(dem_list)}")
         bands_dict.update(self._load_dem(dem_list, resolution=resolution, size=size))
 
         # Add Clouds
+        LOGGER.debug(f"Loading Cloud bands {to_str(clouds_list)}")
         bands_dict.update(
             self._load_clouds(clouds_list, resolution=resolution, size=size)
         )
@@ -337,13 +361,13 @@ class OpticalProduct(Product):
         """
         Get Mean Sun angles (Azimuth and Zenith angles)
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.get_mean_sun_angles()
-        (149.148155074489, 32.6627897525474)
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_mean_sun_angles()
+            (149.148155074489, 32.6627897525474)
 
         Returns:
             (float, float): Mean Azimuth and Zenith angle
@@ -375,7 +399,7 @@ class OpticalProduct(Product):
 
         # Get Hillshade path
         hillshade_dem = os.path.join(
-            self.output, f"{self.condensed_name}_HILLSHADE.tif"
+            self._tmp_process, f"{self.condensed_name}_HILLSHADE.tif"
         )
         if os.path.isfile(hillshade_dem):
             LOGGER.debug(
@@ -386,8 +410,9 @@ class OpticalProduct(Product):
 
             # Get angles
             mean_azimuth_angle, mean_zenith_angle = self.get_mean_sun_angles()
-            zenith = 90.0 - mean_zenith_angle
-            azimuth = mean_azimuth_angle
+
+            # Altitude of the light, in degrees. 90 if the light comes from above the DEM, 0 if it is raking light.
+            alt = 90 - mean_zenith_angle
 
             # Run cmd
             cmd_hillshade = [
@@ -401,15 +426,18 @@ class OpticalProduct(Product):
                 "-z",
                 "1",
                 "-az",
-                azimuth,
+                mean_azimuth_angle,
                 "-alt",
-                zenith,
+                alt,
                 "-of",
                 "GTiff",
                 strings.to_cmd_string(hillshade_dem),
             ]
             # Run command
-            misc.run_cli(cmd_hillshade)
+            try:
+                misc.run_cli(cmd_hillshade)
+            except RuntimeError as ex:
+                raise RuntimeError("Something went wrong with gdaldem!") from ex
 
         return hillshade_dem
 
@@ -417,7 +445,7 @@ class OpticalProduct(Product):
         self, bands: list, resolution: float = None, size: Union[list, tuple] = None
     ) -> dict:
         """
-        Load cloud files as numpy arrays with the same resolution (and same metadata).
+        Load cloud files as xarrays.
 
         Args:
             bands (list): List of the wanted bands
@@ -443,6 +471,35 @@ class OpticalProduct(Product):
             XDS_TYPE: Mask as xarray
         """
         mask = xds.copy(data=np.where(cond, self._mask_true, self._mask_false))
-        mask = mask.where(nodata == 0, np.nan)
+        mask = mask.where(nodata == 0)
 
         return mask
+
+    def _get_clean_band_path(self, band: obn, resolution: float = None):
+        """
+        Get clean band path.
+
+        The clean band is the opened band where invalid pixels have been managed.
+
+        Args:
+            band (OpticalBandNames): Wanted band
+            resolution (float): Band resolution in meters
+
+        Returns:
+            str: Clean band path
+        """
+        if resolution is not None:
+            if isinstance(resolution, (list, tuple)):
+                res_str = "_".join(str([round(resolution, 2)])) + "m"
+            else:
+                res_str = f"{resolution:.2f}m"
+        else:
+            try:
+                res_str = f"{self.resolution:.2f}m"
+            except ValueError:
+                res_str = ""
+
+        return os.path.join(
+            self._tmp_process,
+            f"{self.condensed_name}_{band.name}_{res_str.replace('.', '-')}_clean.tif",
+        )
