@@ -16,7 +16,6 @@
 # limitations under the License.
 """ Sentinel-2 products """
 
-import glob
 import logging
 import os
 import re
@@ -38,9 +37,9 @@ from eoreader.bands.bands import OpticalBandNames as obn
 from eoreader.exceptions import InvalidProductError, InvalidTypeError
 from eoreader.products.optical.optical_product import OpticalProduct
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
-from sertit import files, rasters
+from sertit import files, rasters, vectors
 from sertit.misc import ListEnum
-from sertit.rasters import ORIGIN_DTYPE, XDS_TYPE
+from sertit.rasters import XDS_TYPE
 
 LOGGER = logging.getLogger(EOREADER_NAME)
 
@@ -108,7 +107,7 @@ class S2Product(OpticalProduct):
         return self.split_name[-2]
 
     def _set_product_type(self) -> None:
-        """Get products type"""
+        """Set products type"""
         if "MSIL2A" in self.name:
             self.product_type = S2ProductType.L2A
             self.band_names.map_bands(
@@ -151,16 +150,16 @@ class S2Product(OpticalProduct):
 
     def footprint(self) -> gpd.GeoDataFrame:
         """
-        Get UTM footprint of the products (without nodata, *in french == emprise utile*)
+        Get UTM footprint in UTM of the products (without nodata, *in french == emprise utile*)
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.footprint()
-           index                                           geometry
-        0      0  POLYGON ((199980.000 4500000.000, 199980.000 4...
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.footprint()
+               index                                           geometry
+            0      0  POLYGON ((199980.000 4500000.000, 199980.000 4...
 
         Returns:
             gpd.GeoDataFrame: Footprint as a GeoDataFrame
@@ -174,15 +173,15 @@ class S2Product(OpticalProduct):
         """
         Get the product's acquisition datetime, with format `YYYYMMDDTHHMMSS` <-> `%Y%m%dT%H%M%S`
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.get_datetime(as_datetime=True)
-        datetime.datetime(2020, 8, 24, 11, 6, 31)
-        >>> prod.get_datetime(as_datetime=False)
-        '20200824T110631'
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_datetime(as_datetime=True)
+            datetime.datetime(2020, 8, 24, 11, 6, 31)
+            >>> prod.get_datetime(as_datetime=False)
+            '20200824T110631'
 
         Args:
             as_datetime (bool): Return the date as a datetime.datetime. If false, returns a string.
@@ -265,17 +264,17 @@ class S2Product(OpticalProduct):
         """
         Return the paths of required bands.
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> from eoreader.bands.alias import *
-        >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.get_band_paths([GREEN, RED])
-        {
-            <OpticalBandNames.GREEN: 'GREEN'>: 'zip+file://S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip!/S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE/GRANULE/L1C_T30TTK_A027018_20200824T111345/IMG_DATA/T30TTK_20200824T110631_B03.jp2',
-            <OpticalBandNames.RED: 'RED'>: 'zip+file://S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip!/S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE/GRANULE/L1C_T30TTK_A027018_20200824T111345/IMG_DATA/T30TTK_20200824T110631_B04.jp2'
-        }
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> from eoreader.bands.alias import *
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_band_paths([GREEN, RED])
+            {
+                <OpticalBandNames.GREEN: 'GREEN'>: 'zip+file://S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip!/S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE/GRANULE/L1C_T30TTK_A027018_20200824T111345/IMG_DATA/T30TTK_20200824T110631_B03.jp2',
+                <OpticalBandNames.RED: 'RED'>: 'zip+file://S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip!/S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE/GRANULE/L1C_T30TTK_A027018_20200824T111345/IMG_DATA/T30TTK_20200824T110631_B04.jp2'
+            }
 
         Args:
             band_list (list): List of the wanted bands
@@ -287,55 +286,63 @@ class S2Product(OpticalProduct):
         band_folders = self._get_res_band_folder(band_list, resolution)
         band_paths = {}
         for band in band_list:
-            try:
-                if self.is_archived:
-                    band_paths[band] = files.get_archived_rio_path(
-                        self.path,
-                        f".*{band_folders[band]}.*_B{self.band_names[band]}.*.jp2",
-                    )
-                else:
-                    band_paths[band] = files.get_file_in_dir(
-                        band_folders[band],
-                        "_B" + self.band_names[band],
-                        extension="jp2",
-                    )
-            except (FileNotFoundError, IndexError) as ex:
-                raise InvalidProductError(
-                    f"Non existing {band} ({self.band_names[band]}) band for {self.path}"
-                ) from ex
+            # Get clean band path
+            clean_band = self._get_clean_band_path(band, resolution=resolution)
+            if os.path.isfile(clean_band):
+                band_paths[band] = clean_band
+            else:
+                try:
+                    if self.is_archived:
+                        band_paths[band] = files.get_archived_rio_path(
+                            self.path,
+                            f".*{band_folders[band]}.*_B{self.band_names[band]}.*.jp2",
+                        )
+                    else:
+                        band_paths[band] = files.get_file_in_dir(
+                            band_folders[band],
+                            "_B" + self.band_names[band],
+                            extension="jp2",
+                        )
+                except (FileNotFoundError, IndexError) as ex:
+                    raise InvalidProductError(
+                        f"Non existing {band} ({self.band_names[band]}) band for {self.path}"
+                    ) from ex
 
         return band_paths
 
     def _read_band(
         self,
         path: str,
+        band: BandNames = None,
         resolution: Union[tuple, list, float] = None,
         size: Union[list, tuple] = None,
     ) -> XDS_TYPE:
         """
-        Read band from a dataset.
+        Read band from disk.
 
         .. WARNING::
-            Invalid pixels are not managed here !
+            Invalid pixels are not managed here
 
         Args:
             path (str): Band path
+            band (BandNames): Band to read
             resolution (Union[tuple, list, float]): Resolution of the wanted band, in dataset resolution unit (X, Y)
             size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
         Returns:
-            XDS_TYPE: Radiometrically coherent band, saved as float 32
+            XDS_TYPE: Band xarray
 
         """
         # Read band
-        band = rasters.read(
+        band_xda = rasters.read(
             path, resolution=resolution, size=size, resampling=Resampling.bilinear
         )
 
         # Compute the correct radiometry of the band
-        if band.attrs[ORIGIN_DTYPE] == "uint16":
-            band /= 10000.0
+        original_dtype = band_xda.encoding.get("dtype", band_xda.dtype)
+        if original_dtype == "uint16":
+            band_xda /= 10000.0
 
-        return band
+        return band_xda.astype(np.float32)
 
     def open_mask(self, mask_str: str, band: Union[obn, str]) -> gpd.GeoDataFrame:
         """
@@ -350,28 +357,28 @@ class S2Product(OpticalProduct):
         - `DEFECT`: Defective pixels
         - `CLOUDS`, **only with `00` as a band !**
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> from eoreader.bands.alias import *
-        >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-        >>> prod.open_mask("NODATA", GREEN)
-        Empty GeoDataFrame
-        Columns: [geometry]
-        Index: []
-        >>> prod.open_mask("SATURA", GREEN)
-        Empty GeoDataFrame
-        Columns: [geometry]
-        Index: []
-        >>> prod.open_mask("DETFOO", GREEN)
-                                gml_id  ...                                           geometry
-        0  detector_footprint-B03-02-0  ...  POLYGON Z ((199980.000 4500000.000 0.000, 1999...
-        1  detector_footprint-B03-03-1  ...  POLYGON Z ((222570.000 4500000.000 0.000, 2225...
-        2  detector_footprint-B03-05-2  ...  POLYGON Z ((273050.000 4500000.000 0.000, 2730...
-        3  detector_footprint-B03-07-3  ...  POLYGON Z ((309770.000 4453710.000 0.000, 3097...
-        4  detector_footprint-B03-04-4  ...  POLYGON Z ((248080.000 4500000.000 0.000, 2480...
-        5  detector_footprint-B03-06-5  ...  POLYGON Z ((297980.000 4500000.000 0.000, 2979...
-        [6 rows x 3 columns]
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> from eoreader.bands.alias import *
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod.open_mask("NODATA", GREEN)
+            Empty GeoDataFrame
+            Columns: [geometry]
+            Index: []
+            >>> prod.open_mask("SATURA", GREEN)
+            Empty GeoDataFrame
+            Columns: [geometry]
+            Index: []
+            >>> prod.open_mask("DETFOO", GREEN)
+                                    gml_id  ...                                           geometry
+            0  detector_footprint-B03-02-0  ...  POLYGON Z ((199980.000 4500000.000 0.000, 1999...
+            1  detector_footprint-B03-03-1  ...  POLYGON Z ((222570.000 4500000.000 0.000, 2225...
+            2  detector_footprint-B03-05-2  ...  POLYGON Z ((273050.000 4500000.000 0.000, 2730...
+            3  detector_footprint-B03-07-3  ...  POLYGON Z ((309770.000 4453710.000 0.000, 3097...
+            4  detector_footprint-B03-04-4  ...  POLYGON Z ((248080.000 4500000.000 0.000, 2480...
+            5  detector_footprint-B03-06-5  ...  POLYGON Z ((297980.000 4500000.000 0.000, 2979...
+            [6 rows x 3 columns]
 
         Args:
             mask_str (str): Mask name, such as DEFECT, NODATA, SATURA...
@@ -385,23 +392,6 @@ class S2Product(OpticalProduct):
         if mask_str == "CLOUDS":
             band = "00"
 
-        def _open_mask(fct, *args, **kwargs):
-            # Read the GML file
-            try:
-                # Discard some weird error concerning a NULL pointer that outputs a ValueError (as we already except it)
-                fiona_logger = logging.getLogger("fiona._env")
-                fiona_logger.setLevel(logging.CRITICAL)
-
-                # Read mask
-                mask = fct(*args, **kwargs)
-
-                # Set fiona logger back to what it was
-                fiona_logger.setLevel(logging.INFO)
-            except ValueError:
-                mask = gpd.GeoDataFrame(geometry=[], crs=self.crs())
-
-            return mask
-
         # Get QI_DATA path
         if isinstance(band, obn):
             band_name = self.band_names[band]
@@ -417,11 +407,7 @@ class S2Product(OpticalProduct):
                     f".*GRANULE.*QI_DATA.*MSK_{mask_str}_B{band_name}.gml"
                 )
                 with zip_ds.open(list(filter(regex.match, filenames))[0]) as mask_path:
-                    mask = _open_mask(gpd.read_file, mask_path)
-
-            # mask = _open_mask(files.read_archived_vector,
-            #                   self.path,
-            #                   f".*GRANULE.*QI_DATA.*MSK_{mask_str}_B{band_name}\.gml")
+                    mask = vectors.open_gml(mask_path, crs=self.crs())
         else:
             qi_data_path = os.path.join(self.path, "GRANULE", "*", "QI_DATA")
 
@@ -430,7 +416,7 @@ class S2Product(OpticalProduct):
                 qi_data_path, f"MSK_{mask_str}_B{band_name}.gml", exact_name=True
             )
 
-            mask = _open_mask(gpd.read_file, mask_path)
+            mask = vectors.open_gml(mask_path, crs=self.crs())
 
         return mask
 
@@ -467,7 +453,7 @@ class S2Product(OpticalProduct):
         # Rasterize nodata
         mask = features.rasterize(
             nodata_det.geometry,
-            out_shape=(band_arr.rio.width, band_arr.rio.height),
+            out_shape=(band_arr.rio.height, band_arr.rio.width),
             fill=nodata_true,  # Outside detector = nodata
             default_value=nodata_false,  # Inside detector = acceptable value
             transform=band_arr.rio.transform(),
@@ -495,7 +481,7 @@ class S2Product(OpticalProduct):
             # Rasterize mask
             mask_pix = features.rasterize(
                 nodata_pix.geometry,
-                out_shape=(band_arr.rio.width, band_arr.rio.height),
+                out_shape=(band_arr.rio.height, band_arr.rio.width),
                 fill=nodata_false,  # OK pixels = OK value
                 default_value=nodata_true,  # Discarded pixels = nodata
                 transform=band_arr.rio.transform(),
@@ -535,91 +521,59 @@ class S2Product(OpticalProduct):
         Get S2 products condensed name ({date}_S2_{tile}_{product_type}_{processed_hours}).
 
         Returns:
-            str: Condensed S2 name
+            str: Condensed name
         """
         # Used to make the difference between 2 products acquired on the same tile at the same date but cut differently
         proc_time = self.split_name[-1].split("T")[-1]
-        return f"{self.get_datetime()}_S2_{self.tile_name}_{self.product_type.value}_{proc_time}"
+        return f"{self.get_datetime()}_{self.platform.name}_{self.tile_name}_{self.product_type.value}_{proc_time}"
 
     def get_mean_sun_angles(self) -> (float, float):
         """
         Get Mean Sun angles (Azimuth and Zenith angles)
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.get_mean_sun_angles()
-        (149.148155074489, 32.6627897525474)
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_mean_sun_angles()
+            (149.148155074489, 32.6627897525474)
 
         Returns:
             (float, float): Mean Azimuth and Zenith angle
         """
-        # Init angles
-        zenith_angle = None
-        azimuth_angle = None
-
         # Read metadata
-        root, namespace = self.read_mtd()
+        root, _ = self.read_mtd()
 
-        # Open zenith and azimuth angle
-        for element in root:
-            if element.tag == namespace + "Geometric_Info":
-                for node in element:
-                    if node.tag == "Tile_Angles":
-                        mean_sun_angles = node.find("Mean_Sun_Angle")
-                        zenith_angle = float(mean_sun_angles.findtext("ZENITH_ANGLE"))
-                        azimuth_angle = float(mean_sun_angles.findtext("AZIMUTH_ANGLE"))
-                        break  # Only one Mean_Sun_Angle
-                break  # Only one Geometric_Info
-
-        if not zenith_angle or not azimuth_angle:
+        try:
+            mean_sun_angles = root.find(".//Mean_Sun_Angle")
+            zenith_angle = float(mean_sun_angles.findtext("ZENITH_ANGLE"))
+            azimuth_angle = float(mean_sun_angles.findtext("AZIMUTH_ANGLE"))
+        except TypeError:
             raise InvalidProductError("Azimuth or Zenith angles not found")
 
         return azimuth_angle, zenith_angle
 
-    def read_mtd(self) -> (etree._Element, str):
+    def read_mtd(self) -> (etree._Element, dict):
         """
-        Read metadata and outputs the metadata XML root and its namespace
+        Read metadata and outputs the metadata XML root and its namespaces as a dict
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.read_mtd()
-        (<Element {https://psd-14.sentinel2.eo.esa.int/PSD/S2_PDI_Level-2A_Tile_Metadata.xsd}Level-2A_Tile_ID at ...>,
-        '{https://psd-14.sentinel2.eo.esa.int/PSD/S2_PDI_Level-2A_Tile_Metadata.xsd}')
+        .. code-block:: python
 
-        ```
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.read_mtd()
+            (<Element {https://psd-14.sentinel2.eo.esa.int/PSD/S2_PDI_Level-2A_Tile_Metadata.xsd}Level-2A_Tile_ID at ...>,
+            {'nl': '{https://psd-14.sentinel2.eo.esa.int/PSD/S2_PDI_Level-2A_Tile_Metadata.xsd}'})
 
         Returns:
-            (etree._Element, str): Metadata XML root and its namespace
+            (etree._Element, dict): Metadata XML root and its namespaces
         """
-        # Get MTD XML file
-        if self.is_archived:
-            root = files.read_archived_xml(self.path, ".*GRANULE.*\.xml")
-        else:
-            # Open metadata file
-            try:
-                mtd_file = glob.glob(os.path.join(self.path, "GRANULE", "*", "*.xml"))[
-                    0
-                ]
+        mtd_from_path = os.path.join("GRANULE", "*", "*.xml")
+        mtd_archived = ".*GRANULE.*\.xml"
 
-                # pylint: disable=I1101:
-                # Module 'lxml.etree' has no 'parse' member, but source is unavailable.
-                xml_tree = etree.parse(mtd_file)
-                root = xml_tree.getroot()
-            except IndexError as ex:
-                raise InvalidProductError(
-                    f"Metadata file not found in {self.path}"
-                ) from ex
-
-        # Get namespace
-        idx = root.tag.rindex("}")
-        namespace = root.tag[: idx + 1]
-
-        return root, namespace
+        return self._read_mtd(mtd_from_path, mtd_archived)
 
     def _has_cloud_band(self, band: BandNames) -> bool:
         """
@@ -636,7 +590,7 @@ class S2Product(OpticalProduct):
         self, bands: list, resolution: float = None, size: Union[list, tuple] = None
     ) -> dict:
         """
-        Load cloud files as numpy arrays with the same resolution (and same metadata).
+        Load cloud files as xarrays.
 
         Read S2 cloud mask .GML files (both valid for L2A and L1C products).
         https://sentinels.copernicus.eu/web/sentinel/technical-guides/sentinel-2-msi/level-1c/cloud-masks
