@@ -15,12 +15,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """
-Sentinel-2 Theia products
-See [here](https://labo.obs-mip.fr/multitemp/sentinel-2/theias-sentinel-2-l2a-product-format/) for more information.
+Sentinel-2 Theia products.
+See `here <https://labo.obs-mip.fr/multitemp/sentinel-2/theias-sentinel-2-l2a-product-format/>`_ for more information.
 """
 
 import datetime
-import glob
 import logging
 import os
 from functools import reduce
@@ -48,7 +47,8 @@ LOGGER = logging.getLogger(EOREADER_NAME)
 class S2TheiaProduct(OpticalProduct):
     """
     Class of Sentinel-2 Theia Products.
-    See [here](https://labo.obs-mip.fr/multitemp/sentinel-2/theias-sentinel-2-l2a-product-format/) for more information.
+    See `here <https://labo.obs-mip.fr/multitemp/sentinel-2/theias-sentinel-2-l2a-product-format/>`_
+    for more information.
     """
 
     def _post_init(self) -> None:
@@ -81,7 +81,7 @@ class S2TheiaProduct(OpticalProduct):
         return self.split_name[3]
 
     def _set_product_type(self) -> None:
-        """Get products type"""
+        """Set products type"""
         self.product_type = S2ProductType.L2A
         self.band_names.map_bands(
             {
@@ -104,20 +104,20 @@ class S2TheiaProduct(OpticalProduct):
 
     def footprint(self) -> gpd.GeoDataFrame:
         """
-        Get real footprint of the products (without nodata, in french == emprise utile)
+        Get real footprint in UTM of the products (without nodata, in french == emprise utile)
 
         .. WARNING::
             As Landsat 7 is broken (with nodata stripes all over the bands),
             the footprint is not easily computed and may take some time to be delivered.
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"LC08_L1GT_023030_20200518_20200527_01_T2"
-        >>> prod = Reader().open(path)
-        >>> prod.footprint()
-           index                                           geometry
-        0      0  POLYGON ((366165.000 4899735.000, 366165.000 4...
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"LC08_L1GT_023030_20200518_20200527_01_T2"
+            >>> prod = Reader().open(path)
+            >>> prod.footprint()
+               index                                           geometry
+            0      0  POLYGON ((366165.000 4899735.000, 366165.000 4...
 
         Overload of the generic function because landsat nodata seems to be different in QA than in regular bands.
         Indeed, nodata pixels vary according to the band sensor footprint,
@@ -145,15 +145,15 @@ class S2TheiaProduct(OpticalProduct):
         """
         Get the product's acquisition datetime, with format `YYYYMMDDTHHMMSS` <-> `%Y%m%dT%H%M%S`
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2"
-        >>> prod = Reader().open(path)
-        >>> prod.get_datetime(as_datetime=True)
-        datetime.datetime(2019, 6, 25, 10, 57, 28, 756000), fetched from metadata, so we have the ms
-        >>> prod.get_datetime(as_datetime=False)
-        '20190625T105728'
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2"
+            >>> prod = Reader().open(path)
+            >>> prod.get_datetime(as_datetime=True)
+            datetime.datetime(2019, 6, 25, 10, 57, 28, 756000), fetched from metadata, so we have the ms
+            >>> prod.get_datetime(as_datetime=False)
+            '20190625T105728'
 
         Args:
             as_datetime (bool): Return the date as a datetime.datetime. If false, returns a string.
@@ -173,17 +173,17 @@ class S2TheiaProduct(OpticalProduct):
         """
         Return the paths of required bands.
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> from eoreader.bands.alias import *
-        >>> path = r"SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2"
-        >>> prod = Reader().open(path)
-        >>> prod.get_band_paths([GREEN, RED])
-        {
-            <OpticalBandNames.GREEN: 'GREEN'>: 'SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2\\SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2_FRE_B3.tif',
-            <OpticalBandNames.RED: 'RED'>: 'SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2\\SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2_FRE_B4.tif'
-        }
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> from eoreader.bands.alias import *
+            >>> path = r"SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2"
+            >>> prod = Reader().open(path)
+            >>> prod.get_band_paths([GREEN, RED])
+            {
+                <OpticalBandNames.GREEN: 'GREEN'>: 'SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2\\SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2_FRE_B3.tif',
+                <OpticalBandNames.RED: 'RED'>: 'SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2\\SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2_FRE_B4.tif'
+            }
 
         Args:
             band_list (list): List of the wanted bands
@@ -193,51 +193,58 @@ class S2TheiaProduct(OpticalProduct):
             dict: Dictionary containing the path of each queried band
         """
         band_paths = {}
-        for band in band_list:
-            try:
-                if self.is_archived:
-                    band_paths[band] = files.get_archived_rio_path(
-                        self.path, f".*FRE_B{self.band_names[band]}\.tif"
-                    )
-                else:
-                    band_paths[band] = files.get_file_in_dir(
-                        self.path, f"FRE_B{self.band_names[band]}.tif"
-                    )
-            except (FileNotFoundError, IndexError) as ex:
-                raise InvalidProductError(
-                    f"Non existing {band} ({self.band_names[band]}) band for {self.path}"
-                ) from ex
+        for band in band_list:  # Get clean band path
+            clean_band = self._get_clean_band_path(band, resolution=resolution)
+            if os.path.isfile(clean_band):
+                band_paths[band] = clean_band
+            else:
+                try:
+                    if self.is_archived:
+                        band_paths[band] = files.get_archived_rio_path(
+                            self.path, f".*FRE_B{self.band_names[band]}\.tif"
+                        )
+                    else:
+                        band_paths[band] = files.get_file_in_dir(
+                            self.path, f"FRE_B{self.band_names[band]}.tif"
+                        )
+                except (FileNotFoundError, IndexError) as ex:
+                    raise InvalidProductError(
+                        f"Non existing {band} ({self.band_names[band]}) band for {self.path}"
+                    ) from ex
 
         return band_paths
 
     def _read_band(
         self,
         path: str,
+        band: BandNames = None,
         resolution: Union[tuple, list, float] = None,
         size: Union[list, tuple] = None,
     ) -> XDS_TYPE:
         """
-        Read band from a dataset
+        Read band from disk.
 
         .. WARNING::
-            Invalid pixels are not managed here!
+            Invalid pixels are not managed here
 
         Args:
             path (str): Band path
+            band (BandNames): Band to read
             resolution (Union[tuple, list, float]): Resolution of the wanted band, in dataset resolution unit (X, Y)
             size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
         Returns:
-            XDS_TYPE: Radiometrically coherent band, saved as float 32
+            XDS_TYPE: Band xarray
+
         """
         # Read band
-        band = rasters.read(
+        band_xda = rasters.read(
             path, resolution=resolution, size=size, resampling=Resampling.bilinear
-        )
+        ).astype(np.float32)
 
         # Compute the correct radiometry of the band
-        band = band / 10000.0
+        band_xda = band_xda / 10000.0
 
-        return band
+        return band_xda
 
     # pylint: disable=R0913
     # R0913: Too many arguments (6/5) (too-many-arguments)
@@ -250,7 +257,7 @@ class S2TheiaProduct(OpticalProduct):
     ) -> XDS_TYPE:
         """
         Manage invalid pixels (Nodata, saturated, defective...)
-        See [here](https://labo.obs-mip.fr/multitemp/sentinel-2/theias-sentinel-2-l2a-product-format/) for more
+        See `here <https://labo.obs-mip.fr/multitemp/sentinel-2/theias-sentinel-2-l2a-product-format/>`_ for more
         information.
 
         Args:
@@ -338,7 +345,7 @@ class S2TheiaProduct(OpticalProduct):
         size: Union[list, tuple] = None,
     ) -> np.ndarray:
         """
-        Open a Sentinel-2 THEIA mask.
+        Open a Sentinel-2 THEIA mask as a numpy array.
 
         - Opens the saturation and defective mask to the correct bit ID corresponding to the given band.
         - Opens the nodata binary mask
@@ -346,7 +353,7 @@ class S2TheiaProduct(OpticalProduct):
 
         Do not open cloud mask with this function. Use `load` instead.
 
-        See [here](https://labo.obs-mip.fr/multitemp/sentinel-2/theias-sentinel-2-l2a-product-format/) for more
+        See `here <https://labo.obs-mip.fr/multitemp/sentinel-2/theias-sentinel-2-l2a-product-format/>`_ for more
         information.
 
         Accepted mask IDs:
@@ -357,15 +364,14 @@ class S2TheiaProduct(OpticalProduct):
         - `MG2`: Geophysical mask (classification)
         - `IAB`: Mask where water vapor and TOA pixels have been interpolated
 
+        .. code-block:: python
 
-        ```python
-        >>> from eoreader.bands.alias import *
-        >>> from eoreader.reader import Reader
-        >>> path = r"SENTINEL2B_20190401-105726-885_L2A_T31UEQ_D_V2-0.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.open_mask("EDG", GREEN)
-        array([[[0, ..., 0]]], dtype=uint8)
-        ```
+            >>> from eoreader.bands.alias import *
+            >>> from eoreader.reader import Reader
+            >>> path = r"SENTINEL2B_20190401-105726-885_L2A_T31UEQ_D_V2-0.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.open_mask("EDG", GREEN)
+            array([[[0, ..., 0]]], dtype=uint8)
 
         Args:
             mask_id: Mask ID
@@ -443,10 +449,10 @@ class S2TheiaProduct(OpticalProduct):
 
     def _get_condensed_name(self) -> str:
         """
-        Get S2 products condensed name ({date}_S2_{tile]_{product_type}).
+        Get products condensed name ({date}_S2THEIA_{tile]_{product_type}).
 
         Returns:
-            str: Condensed S2 name
+            str: Condensed name
         """
         return (
             f"{self.get_datetime()}_S2THEIA_{self.tile_name}_{self.product_type.value}"
@@ -456,13 +462,13 @@ class S2TheiaProduct(OpticalProduct):
         """
         Get Mean Sun angles (Azimuth and Zenith angles)
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2"
-        >>> prod = Reader().open(path)
-        >>> prod.get_mean_sun_angles()
-        (154.554755774838, 27.5941391571236)
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2"
+            >>> prod = Reader().open(path)
+            >>> prod.get_mean_sun_angles()
+            (154.554755774838, 27.5941391571236)
 
         Returns:
             (float, float): Mean Azimuth and Zenith angle
@@ -474,58 +480,34 @@ class S2TheiaProduct(OpticalProduct):
         # Get MTD XML file
         root, _ = self.read_mtd()
 
-        # Open zenith and azimuth angle
-        for element in root:
-            if element.tag == "Geometric_Informations":
-                for node in element:
-                    if node.tag == "Mean_Value_List":
-                        mean_sun_angles = node.find("Sun_Angles")
-                        zenith_angle = float(mean_sun_angles.findtext("ZENITH_ANGLE"))
-                        azimuth_angle = float(mean_sun_angles.findtext("AZIMUTH_ANGLE"))
-                        break  # Only one Mean_Sun_Angle
-                break  # Only one Geometric_Info
-
-        if not zenith_angle or not azimuth_angle:
+        try:
+            mean_sun_angles = root.find(".//Sun_Angles")
+            zenith_angle = float(mean_sun_angles.findtext("ZENITH_ANGLE"))
+            azimuth_angle = float(mean_sun_angles.findtext("AZIMUTH_ANGLE"))
+        except TypeError:
             raise InvalidProductError("Azimuth or Zenith angles not found")
 
         return azimuth_angle, zenith_angle
 
-    def read_mtd(self) -> (etree._Element, str):
+    def read_mtd(self) -> (etree._Element, dict):
         """
-        Read metadata and outputs the metadata XML root and its namespace
+        Read metadata and outputs the metadata XML root and its namespaces as a dict
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"SENTINEL2B_20190401-105726-885_L2A_T31UEQ_D_V2-0.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.read_mtd()
-        (<Element Muscate_Metadata_Document at 0x252d2071e88>, '')
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"SENTINEL2B_20190401-105726-885_L2A_T31UEQ_D_V2-0.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.read_mtd()
+            (<Element Muscate_Metadata_Document at 0x252d2071e88>, {})
 
         Returns:
-            (etree._Element, str): Metadata XML root and its namespace
+            (etree._Element, dict): Metadata XML root and its namespaces
         """
-        # Get MTD XML file
-        if self.is_archived:
-            root = files.read_archived_xml(self.path, ".*MTD_ALL\.xml")
-        else:
-            # Open metadata file
-            try:
-                mtd_xml = glob.glob(os.path.join(self.path, "*MTD_ALL.xml"))[0]
+        mtd_from_path = "*MTD_ALL.xml"
+        mtd_archived = ".*MTD_ALL\.xml"
 
-                # pylint: disable=I1101:
-                # Module 'lxml.etree' has no 'parse' member, but source is unavailable.
-                xml_tree = etree.parse(mtd_xml)
-                root = xml_tree.getroot()
-            except IndexError as ex:
-                raise InvalidProductError(
-                    f"Metadata file not found in {self.path}"
-                ) from ex
-
-        # Get namespace
-        namespace = ""
-
-        return root, namespace
+        return self._read_mtd(mtd_from_path, mtd_archived)
 
     def _has_cloud_band(self, band: BandNames) -> bool:
         """
@@ -537,7 +519,7 @@ class S2TheiaProduct(OpticalProduct):
         self, bands: list, resolution: float = None, size: Union[list, tuple] = None
     ) -> dict:
         """
-        Load cloud files as numpy arrays with the same resolution (and same metadata).
+        Load cloud files as xarrays.
 
         Read S2 Theia cloud mask:
         https://labo.obs-mip.fr/multitemp/sentinel-2/theias-sentinel-2-l2a-product-format/
@@ -571,7 +553,7 @@ class S2TheiaProduct(OpticalProduct):
                 resolution=resolution,
                 size=size,
                 resampling=Resampling.nearest,
-            )
+            ).astype(np.float32)
 
             # Get nodata mask
             nodata = self.open_mask("EDG", res_id, resolution=resolution, size=size)
