@@ -92,13 +92,17 @@ class S3Product(OpticalProduct):
     """
 
     def __init__(
-        self, product_path: str, archive_path: str = None, output_path=None
+        self,
+        product_path: str,
+        archive_path: str = None,
+        output_path: str = None,
+        remove_tmp: bool = False,
     ) -> None:
         self._instrument_name = None
         self._data_type = None
         self._snap_no_data = -1
         super().__init__(
-            product_path, archive_path, output_path
+            product_path, archive_path, output_path, remove_tmp
         )  # Order is important here
 
     def _post_init(self) -> None:
@@ -120,7 +124,7 @@ class S3Product(OpticalProduct):
         return def_res
 
     def _set_product_type(self) -> None:
-        """Get products type"""
+        """Set products type"""
         # Product type
         if self.name[7] != "1":
             raise InvalidTypeError("Only L1 products are used for Sentinel-3 data.")
@@ -187,16 +191,16 @@ class S3Product(OpticalProduct):
 
     def footprint(self) -> gpd.GeoDataFrame:
         """
-        Get UTM footprint of the products (without nodata, *in french == emprise utile*)
+        Get UTM footprint in UTM of the products (without nodata, *in french == emprise utile*)
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.footprint()
-           index                                           geometry
-        0      0  POLYGON ((199980.000 4500000.000, 199980.000 4...
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.footprint()
+               index                                           geometry
+            0      0  POLYGON ((199980.000 4500000.000, 199980.000 4...
 
         Returns:
             gpd.GeoDataFrame: Footprint as a GeoDataFrame
@@ -209,15 +213,15 @@ class S3Product(OpticalProduct):
         """
         Get the product's acquisition datetime, with format `YYYYMMDDTHHMMSS` <-> `%Y%m%dT%H%M%S`
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = "S3B_SL_1_RBT____20191115T233722_20191115T234022_20191117T031722_0179_032_144_3420_LN2_O_NT_003.SEN3"
-        >>> prod = Reader().open(path)
-        >>> prod.get_datetime(as_datetime=True)
-        datetime.datetime(2019, 11, 15, 23, 37, 22)
-        >>> prod.get_datetime(as_datetime=False)
-        '20191115T233722'
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = "S3B_SL_1_RBT____20191115T233722_20191115T234022_20191117T031722_0179_032_144_3420_LN2_O_NT_003.SEN3"
+            >>> prod = Reader().open(path)
+            >>> prod.get_datetime(as_datetime=True)
+            datetime.datetime(2019, 11, 15, 23, 37, 22)
+            >>> prod.get_datetime(as_datetime=False)
+            '20191115T233722'
 
         Args:
             as_datetime (bool): Return the date as a datetime.datetime. If false, returns a string.
@@ -351,19 +355,19 @@ class S3Product(OpticalProduct):
 
         .. WARNING:: If not existing, this function will orthorectify your bands !
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> from eoreader.bands.alias import *
-        >>> path = "S3B_SL_1_RBT____20191115T233722_20191115T234022_20191117T031722_0179_032_144_3420_LN2_O_NT_003.SEN3"
-        >>> prod = Reader().open(path)
-        >>> prod.get_band_paths([GREEN, RED])
-        Executing processing graph
-        ...11%...21%...31%...42%...52%...62%...73%...83%... done.
-        {
-            <OpticalBandNames.GREEN: 'GREEN'>: '20191115T233722_S3_SLSTR_RBT\\S1_reflectance.tif',
-            <OpticalBandNames.RED: 'RED'>: '20191115T233722_S3_SLSTR_RBT\\S2_reflectance.tif',
-        }
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> from eoreader.bands.alias import *
+            >>> path = "S3B_SL_1_RBT____20191115T233722_20191115T234022_20191117T031722_0179_032_144_3420_LN2_O_NT_003.SEN3"
+            >>> prod = Reader().open(path)
+            >>> prod.get_band_paths([GREEN, RED])
+            Executing processing graph
+            ...11%...21%...31%...42%...52%...62%...73%...83%... done.
+            {
+                <OpticalBandNames.GREEN: 'GREEN'>: '20191115T233722_S3_SLSTR_RBT\\S1_reflectance.tif',
+                <OpticalBandNames.RED: 'RED'>: '20191115T233722_S3_SLSTR_RBT\\S2_reflectance.tif',
+            }
 
         Args:
             band_list (list): List of the wanted bands
@@ -375,39 +379,47 @@ class S3Product(OpticalProduct):
         band_paths = {}
         use_snap = False
         for band in band_list:
-            # Get standard band names
-            band_name = self._get_band_filename(band)
+            # Get clean band path
+            clean_band = self._get_clean_band_path(band, resolution=resolution)
+            if os.path.isfile(clean_band):
+                band_paths[band] = clean_band
+            else:
+                # Get standard band names
+                band_name = self._get_band_filename(band)
 
-            try:
-                # Try to open converted images
-                band_paths[band] = files.get_file_in_dir(
-                    self._get_band_folder(), band_name + ".tif"
-                )
-            except (FileNotFoundError, TypeError):
-                use_snap = True
+                try:
+                    # Try to open converted images
+                    band_paths[band] = files.get_file_in_dir(
+                        self._get_band_folder(), band_name + ".tif"
+                    )
+                except (FileNotFoundError, TypeError):
+                    use_snap = True
 
-        # If not existing (file or output), convert them
-        if use_snap:
-            all_band_paths = self._preprocess_s3(resolution)
-            band_paths = {band: all_band_paths[band] for band in band_list}
+            # If not existing (file or output), convert them
+            if use_snap:
+                all_band_paths = self._preprocess_s3(resolution)
+                band_paths = {band: all_band_paths[band] for band in band_list}
 
         return band_paths
 
     # pylint: disable=W0613
+
     def _read_band(
         self,
         path: str,
+        band: BandNames = None,
         resolution: Union[tuple, list, float] = None,
         size: Union[list, tuple] = None,
     ) -> XDS_TYPE:
         """
-        Read band from a dataset.
+        Read band from disk.
 
         .. WARNING::
-            Invalid pixels are not managed here !
+            Invalid pixels are not managed here
 
         Args:
-            path (str): Band dataset
+            path (str): Band path
+            band (BandNames): Band to read
             resolution (Union[tuple, list, float]): Resolution of the wanted band, in dataset resolution unit (X, Y)
             size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
         Returns:
@@ -674,12 +686,14 @@ class S3Product(OpticalProduct):
 
                 # Remove tif if already existing
                 # (if we are here, sth has failed when creating them, so delete them all)
-                out_tif = os.path.join(self.output, band_name + ".tif")
+                out_tif = os.path.join(self._tmp_process, band_name + ".tif")
                 if os.path.isfile(out_tif):
                     files.remove(out_tif)
 
                 # Convert to geotiffs and set no data with only keeping the first band
-                arr = rasters.read(rasters.get_dim_img_path(out_dim, snap_band_name))
+                arr = rasters.read(
+                    rasters.get_dim_img_path(out_dim, snap_band_name), masked=False
+                )
                 arr = arr.where(arr != self._snap_no_data, np.nan)
                 rasters.write(arr, out_tif, dtype=np.float32)
 
@@ -687,7 +701,7 @@ class S3Product(OpticalProduct):
         for band in processed_bands:
             filename = self._get_band_filename(band)
             if "exception" not in filename:
-                out_tif = os.path.join(self.output, filename + ".tif")
+                out_tif = os.path.join(self._tmp_process, filename + ".tif")
                 if not os.path.isfile(out_tif):
                     raise FileNotFoundError(
                         f"Error when processing S3 bands with SNAP. Couldn't find {out_tif}"
@@ -755,7 +769,10 @@ class S3Product(OpticalProduct):
             display_snap_opt=LOGGER.level == logging.DEBUG,
         )
         LOGGER.debug("Converting %s", self.name)
-        misc.run_cli(cmd_list)
+        try:
+            misc.run_cli(cmd_list)
+        except RuntimeError as ex:
+            raise RuntimeError("Something went wrong with SNAP!") from ex
 
         return snap_bands.split(",")
 
@@ -763,14 +780,14 @@ class S3Product(OpticalProduct):
         """
         Get UTM extent of the tile, managing the case with not orthorectified bands.
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = "S3B_SL_1_RBT____20191115T233722_20191115T234022_20191117T031722_0179_032_144_3420_LN2_O_NT_003.SEN3"
-        >>> prod = Reader().open(path)
-        >>> prod.utm_extent()
-                                                    geometry
-        0  POLYGON ((1488846.028 6121896.451, 1488846.028...
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = "S3B_SL_1_RBT____20191115T233722_20191115T234022_20191117T031722_0179_032_144_3420_LN2_O_NT_003.SEN3"
+            >>> prod = Reader().open(path)
+            >>> prod.utm_extent()
+                                                        geometry
+            0  POLYGON ((1488846.028 6121896.451, 1488846.028...
 
         Returns:
             gpd.GeoDataFrame: Footprint in UTM
@@ -854,24 +871,24 @@ class S3Product(OpticalProduct):
 
     def _get_condensed_name(self) -> str:
         """
-        Get S2 products condensed name ({date}_S2_{tile]_{product_type}).
+        Get S3 products condensed name ({date}_S3_{tile]_{product_type}).
 
         Returns:
-            str: Condensed S2 name
+            str: Condensed name
         """
-        return f"{self.get_datetime()}_S3_{self.product_type.name}"
+        return f"{self.get_datetime()}_{self.platform.name}_{self.product_type.name}"
 
     def get_mean_sun_angles(self) -> (float, float):
         """
         Get Mean Sun angles (Azimuth and Zenith angles)
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = "S3B_SL_1_RBT____20191115T233722_20191115T234022_20191117T031722_0179_032_144_3420_LN2_O_NT_003.SEN3"
-        >>> prod = Reader().open(path)
-        >>> prod.get_mean_sun_angles()
-        (78.55043955912154, 31.172127033319388)
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = "S3B_SL_1_RBT____20191115T233722_20191115T234022_20191117T031722_0179_032_144_3420_LN2_O_NT_003.SEN3"
+            >>> prod = Reader().open(path)
+            >>> prod.get_mean_sun_angles()
+            (78.55043955912154, 31.172127033319388)
 
         Returns:
             (float, float): Mean Azimuth and Zenith angle
@@ -914,15 +931,15 @@ class S3Product(OpticalProduct):
 
     def read_mtd(self) -> (etree._Element, str):
         """
-        Read metadata and outputs the metadata XML root and its namespace
+        Read metadata and outputs the metadata XML root and its namespaces as a dict
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = "S3B_SL_1_RBT____20191115T233722_20191115T234022_20191117T031722_0179_032_144_3420_LN2_O_NT_003.SEN3"
-        >>> prod = Reader().open(path)
-        >>> prod.read_mtd()
-        (<Element level1Product at 0x1b845b7ab88>, '')
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = "S3B_SL_1_RBT____20191115T233722_20191115T234022_20191117T031722_0179_032_144_3420_LN2_O_NT_003.SEN3"
+            >>> prod = Reader().open(path)
+            >>> prod.read_mtd()
+            (<Element level1Product at 0x1b845b7ab88>, '')
 
         Returns:
             (etree._Element, str): Metadata XML root and its namespace
@@ -938,7 +955,6 @@ class S3Product(OpticalProduct):
 
         - SLSTR does
         - OLCI does not provide any cloud mask
-        ```
         """
         if self._instrument_name == S3Instrument.SLSTR and band in [
             RAW_CLOUDS,
@@ -956,7 +972,7 @@ class S3Product(OpticalProduct):
         self, bands: list, resolution: float = None, size: Union[list, tuple] = None
     ) -> dict:
         """
-        Load cloud files as numpy arrays with the same resolution (and same metadata).
+        Load cloud files as xarrays.
 
         Read S3 SLSTR clouds from the flags file:cloud netcdf file.
         https://sentinels.copernicus.eu/web/sentinel/technical-guides/sentinel-3-slstr/level-1/cloud-identification
@@ -1005,7 +1021,7 @@ class S3Product(OpticalProduct):
                 )
             except FileNotFoundError:
                 self._preprocess_s3(resolution)
-                cloud_path = files.get_file_in_dir(self.output, "cloud_RAD.tif")
+                cloud_path = files.get_file_in_dir(self._tmp_process, "cloud_RAD.tif")
 
             if not cloud_path:
                 raise FileNotFoundError(
@@ -1019,7 +1035,7 @@ class S3Product(OpticalProduct):
                 size=size,
                 resampling=Resampling.nearest,
                 masked=False,
-            )
+            ).astype(np.uint16)
 
             # Get nodata mask
             # nodata = np.where(np.isnan(clouds_array), 1, 0)
