@@ -16,7 +16,7 @@
 # limitations under the License.
 """
 COSMO-SkyMed products.
-More info [here](https://earth.esa.int/documents/10174/465595/COSMO-SkyMed-Mission-Products-Description).
+More info `here <https://earth.esa.int/documents/10174/465595/COSMO-SkyMed-Mission-Products-Description>`_.
 """
 import datetime
 import glob
@@ -48,7 +48,7 @@ warnings.filterwarnings("ignore", category=rasterio.errors.NotGeoreferencedWarni
 class CskProductType(ListEnum):
     """
     COSMO-SkyMed products types.
-    Take a look [here](https://earth.esa.int/documents/10174/465595/COSMO-SkyMed-Mission-Products-Description).
+    Take a look `here <https://earth.esa.int/documents/10174/465595/COSMO-SkyMed-Mission-Products-Description>`_.
     """
 
     RAW = "RAW"
@@ -71,7 +71,7 @@ class CskProductType(ListEnum):
 class CskSensorMode(ListEnum):
     """
     COSMO-SkyMed sensor mode.
-    Take a look [here](https://earth.esa.int/documents/10174/465595/COSMO-SkyMed-Mission-Products-Description)
+    Take a look `here <https://earth.esa.int/documents/10174/465595/COSMO-SkyMed-Mission-Products-Description>`_.
     """
 
     HI = "HI"
@@ -94,7 +94,7 @@ class CskSensorMode(ListEnum):
 class CskPolarization(ListEnum):
     """
     COSMO-SkyMed polarizations used during the acquisition.
-    Take a look [here](https://earth.esa.int/documents/10174/465595/COSMO-SkyMed-Mission-Products-Description).
+    Take a look `here <https://earth.esa.int/documents/10174/465595/COSMO-SkyMed-Mission-Products-Description>`_.
     """
 
     HH = "HH"
@@ -122,17 +122,22 @@ class CskPolarization(ListEnum):
 class CskProduct(SarProduct):
     """
     Class for COSMO-SkyMed Products
-    ```python
-    >>> from eoreader.reader import Reader
-    >>> # CSK products could have any folder but needs to have a .h5 file correctly formatted
-    >>> # ie. "CSKS1_SCS_B_HI_15_HH_RA_SF_20201028224625_20201028224632.h5"
-    >>> path = r"1011117-766193"
-    >>> prod = Reader().open(path)
-    ```
+
+    .. code-block:: python
+
+        >>> from eoreader.reader import Reader
+        >>> # CSK products could have any folder but needs to have a .h5 file correctly formatted
+        >>> # ie. "CSKS1_SCS_B_HI_15_HH_RA_SF_20201028224625_20201028224632.h5"
+        >>> path = r"1011117-766193"
+        >>> prod = Reader().open(path)
     """
 
     def __init__(
-        self, product_path: str, archive_path: str = None, output_path=None
+        self,
+        product_path: str,
+        archive_path: str = None,
+        output_path: str = None,
+        remove_tmp: bool = False,
     ) -> None:
         try:
             self._img_path = glob.glob(os.path.join(product_path, "*.h5"))[0]
@@ -143,7 +148,7 @@ class CskProduct(SarProduct):
         self._real_name = files.get_filename(self._img_path)
 
         # Initialization from the super class
-        super().__init__(product_path, archive_path, output_path)
+        super().__init__(product_path, archive_path, output_path, remove_tmp)
 
     def _set_resolution(self) -> float:
         """
@@ -151,15 +156,11 @@ class CskProduct(SarProduct):
         """
         def_res = None
 
-        # Read metadata
+        # Read metadata for default resolution
         try:
             root, _ = self.read_mtd()
-
-            for element in root:
-                if element.tag == "ProductCharacteristics":
-                    def_res = float(element.findtext("GroundRangeGeometricResolution"))
-                    break
-        except (InvalidProductError, AttributeError):
+            def_res = float(root.findtext(".//GroundRangeGeometricResolution"))
+        except (InvalidProductError, TypeError):
             pass
 
         # If we cannot read it in MTD, initiate survival mode
@@ -198,14 +199,14 @@ class CskProduct(SarProduct):
         Get the WGS84 extent of the file before any reprojection.
         This is useful when the SAR pre-process has not been done yet.
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"1011117-766193"
-        >>> prod = Reader().open(path)
-        >>> prod.wgs84_extent()
-                                                    geometry
-        0  POLYGON ((108.09797 15.61011, 108.48224 15.678...
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"1011117-766193"
+            >>> prod = Reader().open(path)
+            >>> prod.wgs84_extent()
+                                                        geometry
+            0  POLYGON ((108.09797 15.61011, 108.48224 15.678...
 
         Returns:
             gpd.GeoDataFrame: WGS84 extent as a gpd.GeoDataFrame
@@ -228,14 +229,10 @@ class CskProduct(SarProduct):
         def from_str_to_arr(geo_coord: str):
             return np.array(strings.str_to_list(geo_coord), dtype=float)[:2][::-1]
 
-        bl_corner = br_corner = tr_corner = tl_corner = None
-        for element in root:
-            if element.tag == "ProductDefinitionData":
-                bl_corner = from_str_to_arr(element.findtext("GeoCoordBottomLeft"))
-                br_corner = from_str_to_arr(element.findtext("GeoCoordBottomRight"))
-                tl_corner = from_str_to_arr(element.findtext("GeoCoordTopLeft"))
-                tr_corner = from_str_to_arr(element.findtext("GeoCoordTopRight"))
-                break
+        bl_corner = from_str_to_arr(root.findtext(".//GeoCoordBottomLeft"))
+        br_corner = from_str_to_arr(root.findtext(".//GeoCoordBottomRight"))
+        tl_corner = from_str_to_arr(root.findtext(".//GeoCoordTopLeft"))
+        tr_corner = from_str_to_arr(root.findtext(".//GeoCoordTopRight"))
 
         if bl_corner is None:
             raise InvalidProductError("Invalid XML: missing extent.")
@@ -248,7 +245,7 @@ class CskProduct(SarProduct):
         return extent_wgs84
 
     def _set_product_type(self) -> None:
-        """Get products type"""
+        """Set products type"""
         self._get_sar_product_type(
             prod_type_pos=1,
             gdrg_types=CskProductType.DGM,
@@ -275,15 +272,15 @@ class CskProduct(SarProduct):
         """
         Get the product's acquisition datetime, with format `YYYYMMDDTHHMMSS` <-> `%Y%m%dT%H%M%S`
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"1011117-766193"
-        >>> prod = Reader().open(path)
-        >>> prod.get_datetime(as_datetime=True)
-        datetime.datetime(2020, 10, 28, 22, 46, 25)
-        >>> prod.get_datetime(as_datetime=False)
-        '20201028T224625'
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"1011117-766193"
+            >>> prod = Reader().open(path)
+            >>> prod.get_datetime(as_datetime=True)
+            datetime.datetime(2020, 10, 28, 22, 46, 25)
+            >>> prod.get_datetime(as_datetime=False)
+            '20201028T224625'
 
         Args:
             as_datetime (bool): Return the date as a datetime.datetime. If false, returns a string.
@@ -309,35 +306,21 @@ class CskProduct(SarProduct):
         # Use the real name
         return [x for x in self._real_name.split("_") if x]
 
-    def read_mtd(self) -> (etree._Element, str):
+    def read_mtd(self) -> (etree._Element, dict):
         """
-        Read metadata and outputs the metadata XML root and its namespace
+        Read metadata and outputs the metadata XML root and its namespaces as a dict
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"1001513-735093"
-        >>> prod = Reader().open(path)
-        >>> prod.read_mtd()
-        (<Element DeliveryNote at 0x2454ad4ee88>, '')
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"1001513-735093"
+            >>> prod = Reader().open(path)
+            >>> prod.read_mtd()
+            (<Element DeliveryNote at 0x2454ad4ee88>, {})
 
         Returns:
-            (etree._Element, str): Metadata XML root and its namespace
+            (etree._Element, dict): Metadata XML root and its namespaces
         """
-        mtd_name = f"DFDN_{self._real_name}.h5.xml"
-        try:
-            mtd_file = glob.glob(os.path.join(self.path, mtd_name))[0]
+        mtd_from_path = f"DFDN_{self._real_name}.h5.xml"
 
-            # pylint: disable=I1101:
-            # Module 'lxml.etree' has no 'parse' member, but source is unavailable.
-            xml_tree = etree.parse(mtd_file)
-            root = xml_tree.getroot()
-        except IndexError as ex:
-            raise InvalidProductError(
-                f"Metadata file ({mtd_name}) not found in {self.path}"
-            ) from ex
-
-        # Get namespace
-        namespace = ""  # No namespace here
-
-        return root, namespace
+        return self._read_mtd(mtd_from_path)
