@@ -16,7 +16,7 @@
 # limitations under the License.
 """
 RADARSAT-2 products.
-More info [here](https://www.pcigeomatics.com/geomatica-help/references/gdb_r/RADARSAT-2.html#RADARSAT2__rs2_sfs).
+More info `here <https://www.pcigeomatics.com/geomatica-help/references/gdb_r/RADARSAT-2.html#RADARSAT2__rs2_sfs>`_.
 """
 import difflib
 import glob
@@ -48,7 +48,7 @@ warnings.filterwarnings("ignore", category=rasterio.errors.NotGeoreferencedWarni
 class Rs2ProductType(ListEnum):
     """
     RADARSAT-2 projection identifier.
-    Take a look [here](https://www.pcigeomatics.com/geomatica-help/references/gdb_r/RADARSAT-2.html)
+    Take a look `here <https://www.pcigeomatics.com/geomatica-help/references/gdb_r/RADARSAT-2.html>`_.
     """
 
     SLC = "SLC"
@@ -83,7 +83,7 @@ class Rs2ProductType(ListEnum):
 class Rs2SensorMode(ListEnum):
     """
     RADARSAT-2 sensor mode.
-    Take a look [here](https://www.pcigeomatics.com/geomatica-help/references/gdb_r/RADARSAT-2.html)
+    Take a look `here <https://www.pcigeomatics.com/geomatica-help/references/gdb_r/RADARSAT-2.html>`_.
 
     .. WARNING:: The name in the metadata may vary !
     """
@@ -156,7 +156,7 @@ class Rs2SensorMode(ListEnum):
 class Rs2Polarization(ListEnum):
     """
     RADARSAT-2 polarization mode.
-    Take a look [here](https://www.pcigeomatics.com/geomatica-help/references/gdb_r/RADARSAT-2.html#RADARSAT2__rs2_sfs)
+    Take a look `here <https://www.pcigeomatics.com/geomatica-help/references/gdb_r/RADARSAT-2.html#RADARSAT2__rs2_sfs>`_
     """
 
     HH = "HH"
@@ -180,16 +180,10 @@ class Rs2Product(SarProduct):
 
         # Read metadata
         try:
-            root, namespace = self.read_mtd()
-
-            for element in root:
-                if element.tag == namespace + "imageAttributes":
-                    raster_attr = element.find(namespace + "rasterAttributes")
-                    def_res = float(
-                        raster_attr.findtext(namespace + "sampledPixelSpacing")
-                    )
-                    break
-        except (InvalidProductError, AttributeError):
+            root, nsmap = self.read_mtd()
+            namespace = nsmap[None]
+            def_res = float(root.findtext(f"{namespace}sampledPixelSpacing"))
+        except (InvalidProductError, TypeError):
             pass
 
         # If we cannot read it in MTD, initiate survival mode
@@ -260,14 +254,14 @@ class Rs2Product(SarProduct):
         Get the WGS84 extent of the file before any reprojection.
         This is useful when the SAR pre-process has not been done yet.
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"RS2_OK73950_PK661843_DK590667_U25W2_20160228_112418_HH_SGF.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.wgs84_extent()
-                                                    geometry
-        1  POLYGON ((106.57999 -6.47363, 107.06926 -6.473...
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"RS2_OK73950_PK661843_DK590667_U25W2_20160228_112418_HH_SGF.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.wgs84_extent()
+                                                        geometry
+            1  POLYGON ((106.57999 -6.47363, 107.06926 -6.473...
 
         Returns:
             gpd.GeoDataFrame: WGS84 extent as a gpd.GeoDataFrame
@@ -293,7 +287,7 @@ class Rs2Product(SarProduct):
         return gpd.GeoDataFrame(geometry=extent_wgs84.geometry, crs=extent_wgs84.crs)
 
     def _set_product_type(self) -> None:
-        """Get products type"""
+        """Set products type"""
         self._get_sar_product_type(
             prod_type_pos=-1,
             gdrg_types=Rs2ProductType.SGF,
@@ -311,18 +305,13 @@ class Rs2Product(SarProduct):
         Get products type from RADARSAT-2 products name (could check the metadata too)
         """
         # Get metadata
-        root, namespace = self.read_mtd()
+        root, nsmap = self.read_mtd()
+        namespace = nsmap[None]
 
         # Get sensor mode
-        sensor_mode_xml = None
-        for element in root:
-            if element.tag == namespace + "sourceAttributes":
-                radar_param = element.find(namespace + "radarParameters")
-
-                # WARNING: this word may differ from the Enum !!! (no docs available)
-                # Get the closest match
-                sensor_mode_xml = radar_param.findtext(namespace + "acquisitionType")
-                break
+        # WARNING: this word may differ from the Enum !!! (no docs available)
+        # Get the closest match
+        sensor_mode_xml = root.findtext(f".//{namespace}acquisitionType")
 
         if sensor_mode_xml:
             sensor_mode = difflib.get_close_matches(
@@ -339,15 +328,15 @@ class Rs2Product(SarProduct):
         """
         Get the product's acquisition datetime, with format `YYYYMMDDTHHMMSS` <-> `%Y%m%dT%H%M%S`
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"RS2_OK73950_PK661843_DK590667_U25W2_20160228_112418_HH_SGF.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.get_datetime(as_datetime=True)
-        datetime.datetime(2016, 2, 28, 11, 24, 18)
-        >>> prod.get_datetime(as_datetime=False)
-        '20160228T112418'
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"RS2_OK73950_PK661843_DK590667_U25W2_20160228_112418_HH_SGF.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_datetime(as_datetime=True)
+            datetime.datetime(2016, 2, 28, 11, 24, 18)
+            >>> prod.get_datetime(as_datetime=False)
+            '20160228T112418'
 
         Args:
             as_datetime (bool): Return the date as a datetime.datetime. If false, returns a string.
@@ -364,41 +353,23 @@ class Rs2Product(SarProduct):
 
         return date
 
-    def read_mtd(self) -> (etree._Element, str):
+    def read_mtd(self) -> (etree._Element, dict):
         """
-        Read metadata and outputs the metadata XML root and its namespace
+        Read metadata and outputs the metadata XML root and its namespaces as a dict
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"LC08_L1GT_023030_20200518_20200527_01_T2"
-        >>> prod = Reader().open(path)
-        >>> prod.read_mtd()
-        (<Element {http://www.rsi.ca/rs2/prod/xml/schemas}product at 0x1c0efbd37c8>,
-        '{http://www.rsi.ca/rs2/prod/xml/schemas}')
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"LC08_L1GT_023030_20200518_20200527_01_T2"
+            >>> prod = Reader().open(path)
+            >>> prod.read_mtd()
+            (<Element {http://www.rsi.ca/rs2/prod/xml/schemas}product at 0x1c0efbd37c8>,
+            {None: '{http://www.rsi.ca/rs2/prod/xml/schemas}'})
 
         Returns:
-            (etree._Element, str): Metadata XML root and its namespace
+            (etree._Element, dict): Metadata XML root and its namespace
         """
-        # Get MTD XML file
-        if self.is_archived:
-            root = files.read_archived_xml(self.path, ".*product\.xml")
-        else:
-            # Open metadata file
-            try:
-                mtd_file = glob.glob(os.path.join(self.path, "product.xml"))[0]
+        mtd_from_path = "product.xml"
+        mtd_archived = ".*product\.xml"
 
-                # pylint: disable=I1101:
-                # Module 'lxml.etree' has no 'parse' member, but source is unavailable.
-                xml_tree = etree.parse(mtd_file)
-                root = xml_tree.getroot()
-            except IndexError as ex:
-                raise InvalidProductError(
-                    f"Metadata file (product.xml) not found in {self.path}"
-                ) from ex
-
-        # Get namespace
-        idx = root.tag.rindex("}")
-        namespace = root.tag[: idx + 1]
-
-        return root, namespace
+        return self._read_mtd(mtd_from_path, mtd_archived)
