@@ -15,7 +15,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """ Sentinel-1 products """
-import glob
 import logging
 import os
 import re
@@ -33,7 +32,7 @@ from lxml import etree
 from eoreader.exceptions import InvalidProductError, InvalidTypeError
 from eoreader.products.sar.sar_product import SarProduct
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
-from sertit import files, misc, strings, vectors
+from sertit import misc, strings, vectors
 from sertit.misc import ListEnum
 
 LOGGER = logging.getLogger(EOREADER_NAME)
@@ -103,13 +102,8 @@ class S1Product(SarProduct):
         # Read metadata
         try:
             root, _ = self.read_mtd()
-
-            for element in root:
-                if element.tag == "imageAnnotation":
-                    image_info = element.find("imageInformation")
-                    def_res = float(image_info.findtext("rangePixelSpacing"))
-                    break
-        except (InvalidProductError, AttributeError):
+            def_res = float(root.findtext(".//rangePixelSpacing"))
+        except (InvalidProductError, TypeError):
             pass
 
         # If we cannot read it in MTD, initiate survival mode
@@ -151,15 +145,15 @@ class S1Product(SarProduct):
         Get the WGS84 extent of the file before any reprojection.
         This is useful when the SAR pre-process has not been done yet.
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.wgs84_extent()
-                               Name  ...                                           geometry
-        0  Sentinel-1 Image Overlay  ...  POLYGON ((0.85336 42.24660, -2.32032 42.65493,...
-        [1 rows x 12 columns]
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.wgs84_extent()
+                                   Name  ...                                           geometry
+            0  Sentinel-1 Image Overlay  ...  POLYGON ((0.85336 42.24660, -2.32032 42.65493,...
+            [1 rows x 12 columns]
 
         Returns:
             gpd.GeoDataFrame: WGS84 extent as a gpd.GeoDataFrame
@@ -195,7 +189,10 @@ class S1Product(SarProduct):
                         strings.to_cmd_string(gj_preview_overlay),
                         strings.to_cmd_string(preview_overlay),
                     ]
-                    misc.run_cli(cmd_line)
+                    try:
+                        misc.run_cli(cmd_line)
+                    except RuntimeError as ex:
+                        raise RuntimeError("Something went wrong with ogr2ogr!") from ex
 
                     # Open the geojson
                     extent_wgs84 = gpd.read_file(gj_preview_overlay)
@@ -218,7 +215,7 @@ class S1Product(SarProduct):
         return extent_wgs84
 
     def _set_product_type(self) -> None:
-        """Get products type"""
+        """Set products type"""
         self._get_sar_product_type(
             prod_type_pos=2, gdrg_types=S1ProductType.GRD, cplx_types=S1ProductType.SLC
         )
@@ -248,15 +245,15 @@ class S1Product(SarProduct):
         """
         Get the product's acquisition datetime, with format `YYYYMMDDTHHMMSS` <-> `%Y%m%dT%H%M%S`
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.get_datetime(as_datetime=True)
-        datetime.datetime(2019, 12, 15, 6, 9, 6)
-        >>> prod.get_datetime(as_datetime=False)
-        '20191215T060906'
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_datetime(as_datetime=True)
+            datetime.datetime(2019, 12, 15, 6, 9, 6)
+            >>> prod.get_datetime(as_datetime=False)
+            '20191215T060906'
 
         Args:
             as_datetime (bool): Return the date as a datetime.datetime. If false, returns a string.
@@ -271,39 +268,22 @@ class S1Product(SarProduct):
 
         return date
 
-    def read_mtd(self) -> (etree._Element, str):
+    def read_mtd(self) -> (etree._Element, dict):
         """
-        Read metadata and outputs the metadata XML root and its namespace
+        Read metadata and outputs the metadata XML root and its namespaces as a dict
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.read_mtd()
-        (<Element product at 0x1832895d788>, '')
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.read_mtd()
+            (<Element product at 0x1832895d788>, {})
 
         Returns:
-            (etree._Element, str): Metadata XML root and its namespace
+            (etree._Element, dict): Metadata XML root and its namespaces
         """
-        # Get MTD XML file
-        if self.is_archived:
-            root = files.read_archived_xml(self.path, ".*annotation.*\.xml")
-        else:
-            # Open metadata file
-            try:
-                mtd_file = glob.glob(os.path.join(self.path, "annotation", "*.xml"))[0]
+        mtd_from_path = os.path.join("annotation", "*.xml")
+        mtd_archived = ".*annotation.*\.xml"
 
-                # pylint: disable=I1101:
-                # Module 'lxml.etree' has no 'parse' member, but source is unavailable.
-                xml_tree = etree.parse(mtd_file)
-                root = xml_tree.getroot()
-            except IndexError as ex:
-                raise InvalidProductError(
-                    f"Metadata file (product.xml) not found in {self.path}"
-                ) from ex
-
-        # Get namespace
-        namespace = ""
-
-        return root, namespace
+        return self._read_mtd(mtd_from_path, mtd_archived)
