@@ -27,6 +27,7 @@ from typing import Union
 
 import geopandas as gpd
 import numpy as np
+import rioxarray
 from rasterio import crs
 from rasterio.enums import Resampling
 
@@ -41,9 +42,9 @@ from eoreader.bands.alias import (
 from eoreader.bands.bands import BandNames
 from eoreader.bands.bands import SarBandNames as sbn
 from eoreader.bands.bands import SarBands
-from eoreader.env_vars import DSPK_GRAPH, PP_GRAPH, SAR_DEF_RES
+from eoreader.env_vars import DEM_PATH, DSPK_GRAPH, PP_GRAPH, SAR_DEF_RES, SNAP_DEM_NAME
 from eoreader.exceptions import InvalidBandError, InvalidProductError, InvalidTypeError
-from eoreader.products.product import Product, SensorType, path_or_dst
+from eoreader.products.product import Product, SensorType
 from eoreader.reader import Platform
 from eoreader.utils import EOREADER_NAME
 from sertit import files, misc, rasters, snap, strings, vectors
@@ -53,6 +54,59 @@ from sertit.rasters import XDS_TYPE
 LOGGER = logging.getLogger(EOREADER_NAME)
 
 
+@unique
+class SnapDems(ListEnum):
+    """
+    DEM available in SNAP for the Terrain Correction module
+    """
+
+    ACE2_5Min = "ACE2_5Min"
+    """
+    ACE2_5Min, Altimeter Corrected Elevations, Version 2
+    """
+
+    ACE30 = "ACE30"
+    """
+    ACE30:  Altimeter Corrected Elevations
+    """
+
+    ASTER = "ASTER 1sec GDEM"
+    """
+    ASTER 1sec GDEM: Advanced Spaceborne Thermal Emission and Reflection Radiometer
+
+    """
+
+    GLO_30 = "Copernicus 30m Global DEM"
+    """
+    Copernicus 30m Global DEM
+    """
+
+    GLO_90 = "Copernicus 90m Global DEM"
+    """
+    Copernicus 90m Global DEM
+    """
+
+    GETASSE30 = "GETASSE30"
+    """
+    GETASSE30: Global Earth Topography And Sea Surface Elevation at 30 arc second resolution
+    """
+
+    SRTM_1SEC = "SRTM 1Sec HGT"
+    """
+    SRTM 1Sec HGT: Shuttle Radar Topography Mission
+    """
+
+    SRTM_3SEC = "SRTM 3Sec"
+    """
+    SRTM 3Sec: Shuttle Radar Topography Mission
+    """
+
+    EXT_DEM = "External DEM"
+    f"""
+    External DEM, needs `{DEM_PATH}` to be correctly positioned
+    """
+
+
 @unique
 class SarProductType(ListEnum):
     """
@@ -102,7 +156,11 @@ class SarProduct(Product):
     """Super class for SAR Products"""
 
     def __init__(
-        self, product_path: str, archive_path: str = None, output_path=None
+        self,
+        product_path: str,
+        archive_path: str = None,
+        output_path: str = None,
+        remove_tmp: bool = False,
     ) -> None:
         self.sar_prod_type = None
         """SAR product type, either Single Look Complex or Ground Range"""
@@ -120,7 +178,7 @@ class SarProduct(Product):
         self._snap_no_data = 0
 
         # Initialization from the super class
-        super().__init__(product_path, archive_path, output_path)
+        super().__init__(product_path, archive_path, output_path, remove_tmp)
 
     def _post_init(self) -> None:
         """
@@ -137,14 +195,14 @@ class SarProduct(Product):
         """
         Get UTM footprint of the products (without nodata, *in french == emprise utile*)
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.footprint()
-           index                                           geometry
-        0      0  POLYGON ((199980.000 4500000.000, 199980.000 4...
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.footprint()
+               index                                           geometry
+            0      0  POLYGON ((199980.000 4500000.000, 199980.000 4...
 
         Returns:
             gpd.GeoDataFrame: Footprint as a GeoDataFrame
@@ -158,13 +216,13 @@ class SarProduct(Product):
         Get default band:
         The first existing one between `VV` and `HH` for SAR data.
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.get_default_band()
-        <SarBandNames.VV: 'VV'>
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_default_band()
+            <SarBandNames.VV: 'VV'>
 
         Returns:
             str: Default band
@@ -195,15 +253,15 @@ class SarProduct(Product):
 
         .. WARNING:: This functions orthorectifies SAR bands if not existing !
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.get_default_band_path()
-        Executing processing graph
-        ....10%....20%....30%....40%....50%....60%....70%....80%....90% done.
-        '20191215T060906_S1_IW_GRD\\20191215T060906_S1_IW_GRD_VV.tif'
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_default_band_path()
+            Executing processing graph
+            ....10%....20%....30%....40%....50%....60%....70%....80%....90% done.
+            '20191215T060906_S1_IW_GRD\\20191215T060906_S1_IW_GRD_VV.tif'
 
         Returns:
             str: Default band path
@@ -219,15 +277,15 @@ class SarProduct(Product):
         Get the WGS84 extent of the file before any reprojection.
         This is useful when the SAR pre-process has not been done yet.
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.wgs84_extent()
-                               Name  ...                                           geometry
-        0  Sentinel-1 Image Overlay  ...  POLYGON ((0.85336 42.24660, -2.32032 42.65493,...
-        [1 rows x 12 columns]
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.wgs84_extent()
+                                   Name  ...                                           geometry
+            0  Sentinel-1 Image Overlay  ...  POLYGON ((0.85336 42.24660, -2.32032 42.65493,...
+            [1 rows x 12 columns]
 
         Returns:
             gpd.GeoDataFrame: WGS84 extent as a gpd.GeoDataFrame
@@ -239,15 +297,15 @@ class SarProduct(Product):
         """
         Get UTM extent of the tile
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.utm_extent()
-                               Name  ...                                           geometry
-        0  Sentinel-1 Image Overlay  ...  POLYGON ((817914.501 4684349.823, 555708.624 4...
-        [1 rows x 12 columns]
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.utm_extent()
+                                   Name  ...                                           geometry
+            0  Sentinel-1 Image Overlay  ...  POLYGON ((817914.501 4684349.823, 555708.624 4...
+            [1 rows x 12 columns]
 
         Returns:
             gpd.GeoDataFrame: Footprint in UTM
@@ -267,13 +325,13 @@ class SarProduct(Product):
         """
         Get UTM projection
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.utm_crs()
-        CRS.from_epsg(32630)
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.utm_crs()
+            CRS.from_epsg(32630)
 
         Returns:
             crs.CRS: CRS object
@@ -346,18 +404,19 @@ class SarProduct(Product):
         """
         Return the paths of required bands.
 
-        .. WARNING:: This functions orthorectifies SAR bands if not existing !
+        .. WARNING:: This functions orthorectifies and despeckles SAR bands if not existing !
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> from eoreader.bands.alias import *
-        >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.get_band_paths([VV, HH])
-        {
-            <SarBandNames.VV: 'VV'>: '20191215T060906_S1_IW_GRD\\20191215T060906_S1_IW_GRD_VV.tif'  # HH doesn't exist
-        }
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> from eoreader.bands.alias import *
+            >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_band_paths([VV, HH])
+            {
+                <SarBandNames.VV: 'VV'>: '20191215T060906_S1_IW_GRD\\20191215T060906_S1_IW_GRD_VV.tif'
+            }
+            >>> # HH doesn't exist
 
         Args:
             band_list (list): List of the wanted bands
@@ -454,84 +513,83 @@ class SarProduct(Product):
 
         .. WARNING:: This functions despeckles SAR bands if not existing !
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> from eoreader.bands.alias import *
-        >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.get_existing_band_paths()
-        Executing processing graph
-        ....10%....20%....30%....40%....50%....60%....70%....80%....90% done.
-        Executing processing graph
-        ....10%....20%....30%....40%....50%....60%....70%....80%....90% done.
-        {
-            <SarBandNames.VV: 'VV'>: '20191215T060906_S1_IW_GRD\\20191215T060906_S1_IW_GRD_VV.tif',
-            <SarBandNames.VH: 'VH'>: '20191215T060906_S1_IW_GRD\\20191215T060906_S1_IW_GRD_VH.tif',
-            <SarBandNames.VV_DSPK: 'VV_DSPK'>: '20191215T060906_S1_IW_GRD\\20191215T060906_S1_IW_GRD_VV_DSPK.tif',
-            <SarBandNames.VH_DSPK: 'VH_DSPK'>: '20191215T060906_S1_IW_GRD\\20191215T060906_S1_IW_GRD_VH_DSPK.tif'
-        }
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> from eoreader.bands.alias import *
+            >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_existing_band_paths()
+            Executing processing graph
+            ....10%....20%....30%....40%....50%....60%....70%....80%....90% done.
+            Executing processing graph
+            ....10%....20%....30%....40%....50%....60%....70%....80%....90% done.
+            {
+                <SarBandNames.VV: 'VV'>: '20191215T060906_S1_IW_GRD\\20191215T060906_S1_IW_GRD_VV.tif',
+                <SarBandNames.VH: 'VH'>: '20191215T060906_S1_IW_GRD\\20191215T060906_S1_IW_GRD_VH.tif',
+                <SarBandNames.VV_DSPK: 'VV_DSPK'>: '20191215T060906_S1_IW_GRD\\20191215T060906_S1_IW_GRD_VV_DSPK.tif',
+                <SarBandNames.VH_DSPK: 'VH_DSPK'>: '20191215T060906_S1_IW_GRD\\20191215T060906_S1_IW_GRD_VH_DSPK.tif'
+            }
 
         Returns:
             dict: Dictionary containing the path of every orthorectified bands
         """
-        # Get raw bands (maximum number of bands)
-        raw_bands = self._get_raw_bands()
-        possible_bands = raw_bands + [
-            sbn.corresponding_despeckle(band) for band in raw_bands
-        ]
-
-        return self.get_band_paths(possible_bands)
+        return self.get_band_paths(self.get_existing_bands())
 
     def get_existing_bands(self) -> list:
         """
         Return the existing orthorectified bands (including despeckle bands).
 
-        .. WARNING:: This functions orthorectifies SAR bands if not existing !
+        .. code-block:: python
 
-        .. WARNING:: This functions despeckles SAR bands if not existing !
-
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> from eoreader.bands.alias import *
-        >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.get_existing_bands()
-        [<SarBandNames.VV: 'VV'>,
-        <SarBandNames.VH: 'VH'>,
-        <SarBandNames.VV_DSPK: 'VV_DSPK'>,
-        <SarBandNames.VH_DSPK: 'VH_DSPK'>]
-        ```
+            >>> from eoreader.reader import Reader
+            >>> from eoreader.bands.alias import *
+            >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_existing_bands()
+            [<SarBandNames.VV: 'VV'>,
+            <SarBandNames.VH: 'VH'>,
+            <SarBandNames.VV_DSPK: 'VV_DSPK'>,
+            <SarBandNames.VH_DSPK: 'VH_DSPK'>]
 
         Returns:
             list: List of existing bands in the products
         """
-        band_paths = self.get_existing_band_paths()
-        return list(band_paths.keys())
+        # Get raw bands (maximum number of bands)
+        raw_bands = self._get_raw_bands()
+        existing_bands = raw_bands + [
+            sbn.corresponding_despeckle(band) for band in raw_bands
+        ]
+
+        return existing_bands
 
     # unused band_name (compatibility reasons)
     # pylint: disable=W0613
-    @path_or_dst
     def _read_band(
         self,
         path: str,
+        band: BandNames = None,
         resolution: Union[tuple, list, float] = None,
         size: Union[list, tuple] = None,
     ) -> XDS_TYPE:
         """
         Read band from disk.
 
+        .. WARNING::
+            Invalid pixels are not managed here
+
         Args:
             path (str): Band path
+            band (BandNames): Band to read
             resolution (Union[tuple, list, float]): Resolution of the wanted band, in dataset resolution unit (X, Y)
             size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
         Returns:
             XDS_TYPE: Band xarray
-        """
 
+        """
         return rasters.read(
             path, resolution=resolution, size=size, resampling=Resampling.bilinear
-        )
+        ).astype(np.float32)
 
     def _load_bands(
         self,
@@ -609,6 +667,10 @@ class SarProduct(Product):
             else:
                 raise InvalidTypeError(f"{band} is neither a band nor an index !")
 
+        # Check if DEM is set and exists
+        if dem_list:
+            self._check_dem_path()
+
         # Load bands
         bands = self._load_bands(band_list, resolution=resolution, size=size)
 
@@ -654,22 +716,60 @@ class SarProduct(Product):
             if not os.path.isfile(pp_dim):
                 def_res = float(os.environ.get(SAR_DEF_RES, self.resolution))
                 res_m = resolution if resolution else def_res
-                res_deg = res_m / 10.0 * 8.983152841195215e-5  # Approx
+                res_deg = (
+                    res_m / 10.0 * 8.983152841195215e-5
+                )  # Approx, shouldn't be used
+
+                # Manage DEM name
+                try:
+                    dem_name = SnapDems.from_value(
+                        os.environ.get(SNAP_DEM_NAME, SnapDems.GETASSE30)
+                    )
+                except AttributeError as ex:
+                    raise ValueError(
+                        f"{SNAP_DEM_NAME} should be chosen among {SnapDems.list_values()}"
+                    ) from ex
+
+                # Manage DEM path
+                if dem_name == SnapDems.EXT_DEM:
+                    dem_path = os.environ.get(DEM_PATH)
+                    if not dem_path:
+                        raise ValueError(
+                            f"You specified '{dem_name.value}' but you didn't give any DEM path. "
+                            f"Please set the environment variable {DEM_PATH} "
+                            f"or change {SNAP_DEM_NAME} to an acceptable SNAP DEM."
+                        )
+                elif dem_name in [SnapDems.GLO_30, SnapDems.GLO_90]:
+                    LOGGER.warning(
+                        "For now, SNAP cannot use Copernicus DEM "
+                        "(see https://forum.step.esa.int/t/terrain-correction-with-copernicus-dem/29025/11). "
+                        "Using GETASSE30 instead."
+                    )
+                    dem_name = SnapDems.GETASSE30
+                else:
+                    dem_path = ""
+
+                # Create SNAP CLI
                 cmd_list = snap.get_gpt_cli(
                     pp_graph,
                     [
                         f"-Pfile={strings.to_cmd_string(self._snap_path)}",
-                        f"-Pout={pp_dim}",
+                        f"-Pdem_name={strings.to_cmd_string(dem_name.value)}",
+                        f"-Pdem_path={strings.to_cmd_string(dem_path)}",
                         f"-Pcrs={self.crs()}",
                         f"-Pres_m={res_m}",
                         f"-Pres_deg={res_deg}",
+                        f"-Pout={strings.to_cmd_string(pp_dim)}",
                     ],
                     display_snap_opt=LOGGER.level == logging.DEBUG,
                 )
 
                 # Pre-process SAR images according to the given graph
                 LOGGER.debug("Pre-process SAR image")
-                misc.run_cli(cmd_list)
+                try:
+                    misc.run_cli(cmd_list)
+                except RuntimeError as ex:
+                    raise RuntimeError("Something went wrong with SNAP!") from ex
 
             # Convert DIMAP images to GeoTiff
             for pol in self.pol_channels:
@@ -714,8 +814,11 @@ class SarProduct(Product):
                 )
 
                 # Pre-process SAR images according to the given graph
-                LOGGER.debug("Despeckle SAR image")
-                misc.run_cli(cmd_list)
+                LOGGER.debug(f"Despeckling {band.name}")
+                try:
+                    misc.run_cli(cmd_list)
+                except RuntimeError as ex:
+                    raise RuntimeError("Something went wrong with SNAP!") from ex
 
             # Convert DIMAP images to GeoTiff
             out = self._write_sar(dspk_dim, band.value, dspk=True)
@@ -739,16 +842,16 @@ class SarProduct(Product):
             img = rasters.get_dim_img_path(dim_path)  # Maybe not the good name
 
         # Open SAR image
-        arr = rasters.read(img)
-        arr = arr.where(arr != self._snap_no_data, np.nan)
+        with rioxarray.open_rasterio(img) as arr:
+            arr = arr.where(arr != self._snap_no_data, np.nan)
 
-        # Save the file as the terrain-corrected image
-        file_path = os.path.join(
-            self.output,
-            f"{files.get_filename(dim_path)}_{pol_up}{'_DSPK' if dspk else ''}.tif",
-        )
-        # WARNING: Set nodata to 0 here as it is the value wanted by SNAP !
-        rasters.write(arr, file_path, dtype=np.float32, nodata=0)
+            # Save the file as the terrain-corrected image
+            file_path = os.path.join(
+                self._tmp_process,
+                f"{files.get_filename(dim_path)}_{pol_up}{'_DSPK' if dspk else ''}.tif",
+            )
+            # WARNING: Set nodata to 0 here as it is the value wanted by SNAP !
+            rasters.write(arr, file_path, dtype=np.float32, nodata=0)
 
         return file_path
 
@@ -776,14 +879,14 @@ class SarProduct(Product):
         """
         Does this products has the specified cloud band ?
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> from eoreader.bands.alias import *
-        >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
-        >>> prod = Reader().open(path)
-        >>> prod.has_cloud_band(CLOUDS)
-        False
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> from eoreader.bands.alias import *
+            >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.has_cloud_band(CLOUDS)
+            False
         """
         return False
 
