@@ -107,6 +107,15 @@ class Platform(ListEnum):
     RS2 = "RADARSAT-2"
     """RADARSAT-2"""
 
+    PLD = "Pleiades"
+    """Pléiades"""
+
+    SPOT7 = "Spot-7"
+    """SPOT-7"""
+
+    SPOT6 = "Spot-6"
+    """SPOT-6"""
+
 
 PLATFORM_REGEX = {
     Platform.S1: r"S1[AB]_(IW|EW|SM|WV)_(RAW|SLC|GRD|OCN)[FHM_]_[0-2]S[SD][HV]_\d{8}T\d{6}_\d{8}T\d{6}_\d{6}_.{11}",
@@ -128,6 +137,9 @@ PLATFORM_REGEX = {
     ],
     Platform.TSX: r"T[SD]X1_SAR__(SSC|MGD|GEC|EEC)_[SR]E___[SH][MCLS]_[SDTQ]_[SD]RA_\d{8}T\d{6}_\d{8}T\d{6}",
     Platform.RS2: r"RS2_OK\d+_PK\d+_DK\d+_.{2,}_\d{8}_\d{6}(_(HH|VV|VH|HV)){1,4}_S(LC|GX|GF|CN|CW|CF|CS|SG|PG)",
+    Platform.PLD: r"IMG_PHR1[AB]_(P|MS|PMS|MS-N|MS-X|PMS-N|PMS-X)_\d{3}",
+    Platform.SPOT7: r"IMG_SPOT7_(P|MS|PMS|MS-N|MS-X|PMS-N|PMS-X)_\d{3}_\w",
+    Platform.SPOT6: r"IMG_SPOT6_(P|MS|PMS|MS-N|MS-X|PMS-N|PMS-X)_\d{3}_\w",
 }
 
 # Not used for now
@@ -149,15 +161,17 @@ MTD_REGEX = {
     Platform.L3: f"{PLATFORM_REGEX[Platform.L3]}_MTL\.txt",
     Platform.L2: f"{PLATFORM_REGEX[Platform.L2]}_MTL\.txt",
     Platform.L1: f"{PLATFORM_REGEX[Platform.L1]}_MTL\.txt",
-    Platform.PLA: r"\d{8}_\d{6}_(\d{2}_|)\w{4}_[13][AB]_.*\.xml",
+    Platform.PLA: r"\d{8}_\d{6}_(\d{2}_|)\w{4}_[13][AB]_.*metadata.*\.xml",
     Platform.CSK: f"{PLATFORM_REGEX[Platform.CSK][1]}\.xml",
     Platform.TSX: f"{PLATFORM_REGEX[Platform.TSX]}\.xml",
     Platform.RS2: [
         r"product\.xml",  # Too generic name, check also a band
-        r"imagery_[HV]{2}.tif",
+        r"imagery_[HV]{2}\.tif",
     ],
+    Platform.PLD: r"DIM_PHR1[AB]_(P|MS|PMS|MS-N|MS-X|PMS-N|PMS-X)_\d{15}_(SEN|PRJ|ORT|MOS)_.{10,}\.XML",
+    Platform.SPOT7: r"DIM_SPOT7_(P|MS|PMS|MS-N|MS-X|PMS-N|PMS-X)_\d{15}_(SEN|PRJ|ORT|MOS)_.{10,}\.XML",
+    Platform.SPOT6: r"DIM_SPOT6_(P|MS|PMS|MS-N|MS-X|PMS-N|PMS-X)_\d{15}_(SEN|PRJ|ORT|MOS)_.{10,}\.XML",
 }
-"""Platform XML regex, mapping every metadata XML to a regex allowing the reader to recognize them (as a fallback)."""
 
 
 class Reader:
@@ -208,23 +222,25 @@ class Reader:
         product_path: str,
         archive_path: str = None,
         output_path: str = None,
-        method=CheckMethod.MTD,
+        method: CheckMethod = CheckMethod.MTD,
+        remove_tmp: bool = False,
     ) -> "Product":  # noqa: F821
         """
         Open the product.
 
-        ```python
-        >>> from eoreader.reader import Reader
-        >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-        >>> Reader().open(path)
-        <eoreader.products.optical.s2_product.S2Product object at 0x000001984986FAC8>
-        ```
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> Reader().open(path)
+            <eoreader.products.optical.s2_product.S2Product object at 0x000001984986FAC8>
 
         Args:
             product_path (str): Product path
             archive_path (str): Archive path
             output_path (str): Output Path
-            look_for_mtd (bool): Look for the metadata. If false, only check the
+            method (CheckMethod): Checking method used to recognize the products
+            remove_tmp (bool): Remove temp files (such as clean or orthorectified bands...) when the product is deleted
 
         Returns:
             Product: Correct products
@@ -253,7 +269,12 @@ class Reader:
                     )
 
                 class_ = getattr(mod, strings.snake_to_camel_case(sat_class))
-                prod = class_(product_path, archive_path, output_path)
+                prod = class_(
+                    product_path=product_path,
+                    archive_path=archive_path,
+                    output_path=output_path,
+                    remove_tmp=remove_tmp,
+                )
                 break
 
         if not prod:
@@ -268,27 +289,28 @@ class Reader:
         """
         Check if the product's name is valid for the given satellite
 
-        ```python
-        >>> from eoreader.reader import Reader, Platform
-        >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-        >>> With IDs
-        >>> Reader().valid_name(path, "S1")
-        False
-        >>> Reader().valid_name(path, "S2")
-        True
 
-        >>> # With names
-        >>> Reader().valid_name(path, "Sentinel-1")
-        False
-        >>> Reader().valid_name(path, "Sentinel-2")
-        True
+        .. code-block:: python
 
-        >>> # With Platform
-        >>> Reader().valid_name(path, Platform.S1)
-        False
-        >>> Reader().valid_name(path, Platform.S2)
-        True
-        ```
+            >>> from eoreader.reader import Reader, Platform
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> With IDs
+            >>> Reader().valid_name(path, "S1")
+            False
+            >>> Reader().valid_name(path, "S2")
+            True
+
+            >>> # With names
+            >>> Reader().valid_name(path, "Sentinel-1")
+            False
+            >>> Reader().valid_name(path, "Sentinel-2")
+            True
+
+            >>> # With Platform
+            >>> Reader().valid_name(path, Platform.S1)
+            False
+            >>> Reader().valid_name(path, Platform.S2)
+            True
 
         Args:
             product_path (str): Product path
@@ -306,27 +328,27 @@ class Reader:
         """
         Check if the product's mtd is in the product folder/archive
 
-        ```python
-        >>> from eoreader.reader import Reader, Platform
-        >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-        >>> With IDs
-        >>> Reader().valid_mtd(path, "S1")
-        False
-        >>> Reader().valid_mtd(path, "S2")
-        True
+        .. code-block:: python
 
-        >>> # With names
-        >>> Reader().valid_mtd(path, "Sentinel-1")
-        False
-        >>> Reader().valid_mtd(path, "Sentinel-2")
-        True
+            >>> from eoreader.reader import Reader, Platform
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> With IDs
+            >>> Reader().valid_mtd(path, "S1")
+            False
+            >>> Reader().valid_mtd(path, "S2")
+            True
 
-        >>> # With Platform
-        >>> Reader().valid_mtd(path, Platform.S1)
-        False
-        >>> Reader().valid_mtd(path, Platform.S2)
-        True
-        ```
+            >>> # With names
+            >>> Reader().valid_mtd(path, "Sentinel-1")
+            False
+            >>> Reader().valid_mtd(path, "Sentinel-2")
+            True
+
+            >>> # With Platform
+            >>> Reader().valid_mtd(path, Platform.S1)
+            False
+            >>> Reader().valid_mtd(path, Platform.S2)
+            True
 
         Args:
             product_path (str): Product path
