@@ -15,8 +15,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """ Utils: mostly getting directories relative to the project """
+import glob
 import logging
 import os
+import platform
 
 EOREADER_NAME = "eoreader"
 DATETIME_FMT = "%Y%m%dT%H%M%S"
@@ -50,4 +52,27 @@ def get_data_dir() -> str:
     Returns:
         str: Data directory
     """
-    return os.path.abspath(os.path.join(get_src_dir(), "data"))
+    data_dir = os.path.abspath(os.path.join(get_src_dir(), "data"))
+    if not os.path.isdir(data_dir) or not os.listdir(data_dir):
+        data_dir = None
+        # Last resort try
+        if platform.system() == "Linux":
+            data_dirs = glob.glob(
+                os.path.join("/usr", "local", "lib", "**", "eoreader", "data"),
+                recursive=True,
+            )
+        else:
+            data_dirs = glob.glob(
+                os.path.join("**", "eoreader", "data"), recursive=True
+            )
+
+        # Look for non empty directories
+        for ddir in data_dirs:
+            if len(os.listdir(ddir)) > 0:
+                data_dir = ddir
+                break
+
+        if not data_dir:
+            raise FileNotFoundError("Impossible to find the data directory.")
+
+    return data_dir
